OC.L10N.register(
    "spreed",
    {
    "a conversation" : "una conversazione",
    "(Duration %s)" : "(Durata %s)",
    "You attended a call with {user1}" : "Hai partecipato a una chiamata con {user1}",
    "_%n guest_::_%n guests_" : ["%n ospite","%n ospiti","%n ospiti"],
    "You attended a call with {user1} and {user2}" : "Hai partecipato a una chiamata con {user1} e {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Hai partecipato a una chiamata con {user1}, {user2} e {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Hai partecipato a una chiamata con {user1}, {user2}, {user3} e {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Hai partecipato a una chiamata con {user1}, {user2}, {user3}, {user4} e {user5}",
    "_%n other_::_%n others_" : ["%n altro","%n altri","%n altri"],
    "{actor} invited you to {call}" : "{actor} ti ha invitato a {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Sei stato invitato a una <strong>conversazione</strong> o hai ricevuto una <strong>chiamata</strong>",
    "Other activities" : "Altre attività",
    "Talk" : "Talk",
    "Guest" : "Ospite",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "## Benvenuti in Nextcloud Talk!\nIn questa conversazione sarai informato sulle nuove funzionalità disponibili in Nextcloud Talk.",
    "## New in Talk %s" : "## Novità in Talk %s",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge e Safari ora possono essere utilizzati per partecipare a chiamate video e audio",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Le conversazioni uno-a-uno ora sono persistenti e non possono essere più trasformate accidentalmente in conversazioni di gruppo. Inoltre, quando uno dei partecipanti abbandona la conversazione, essa non viene più eliminata automaticamente. Solo se entrambi i partecipanti abbandonano, la conversazione viene eliminata dal server",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Ora puoi informare tutti i partecipanti inserendo \"@all\" nella chat",
    "- With the \"arrow-up\" key you can repost your last message" : "- Con il tasto \"freccia su\" puoi richiamare il tuo ultimo messaggio",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talk ora può accettare comandi, invia \"/help\" come un messaggio di chat per vedere se il tuo amministratore li ha configurati",
    "- With projects you can create quick links between conversations, files and other items" : "- Con i progetti puoi creare collegamenti rapidi tra conversazioni, file e altri elementi ",
    "- You can now mention guests in the chat" : "- Ora puoi menzionare gli ospiti nella chat",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Le conversazioni ora possono avere un ingresso. Questo consente ai moderatori di entrare nella chat e preparare la riunione, mentre gli utenti e gli ospiti devono attendere.",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- Ora puoi rispondere direttamente ai messaggi fornendo agli altri utenti altre informazioni sul contesto relativo al tuo messaggio",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- La ricerca di conversazioni e partecipanti ora filtreranno anche le tue conversazioni esistenti, rendendo più semplice trovare conversazioni precedenti",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- Ora puoi aggiungere gruppi di utenti personalizzati alle conversazioni quando l'applicazione Cerchie è installata",
    "- Check out the new grid and call view" : "- Controlla la nuova visualizzazione griglia e chiamata",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Ora puoi inviare e trascinare i file direttamente dal tuo dispositivo nella chat",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- I file condivisi ora vengono aperti direttamente dentro la chat con le applicazioni di visualizzazione",
    "- You can now search for chats and messages in the unified search in the top bar" : "- Ora puoi cercare chat e messaggi nella ricerca unificata nella barra in alto",
    "- Spice up your messages with emojis from the emoji picker" : "- Ravviva i tuoi messaggi con le emoji dal selettore di emoji",
    "- You can now change your camera and microphone while being in a call" : "- È ora possibile cambiare la videocamera e il microfono durante una chiamata",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- Dai alle tue conversazioni un contesto con una descrizione e pubblicala in modo che gli utenti registrati possano trovarla e unirsi in autonomia",
    "- See a read status and send failed messages again" : "- Visualizza uno stato di lettura e invia nuovamente i messaggi non riusciti ",
    "- Raise your hand in a call with the R key" : "- Alza la mano in una chiamata con il tasto R",
    "- Join the same conversation and call from multiple devices" : "- Partecipa alla stessa conversazione e chiama da più dispositivi",
    "- Send voice messages, share your location or contact details" : "- Invia messaggi vocali, condividi la tua posizione o i dettagli di contatto",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- Aggiungi gruppi a una conversazione e i nuovi membri del gruppo verranno automaticamente aggiunti come partecipanti",
    "- A preview of your audio and video is shown before joining a call" : "- Prima di partecipare a una chiamata, viene mostrata un'anteprima dell'audio e del video",
    "- You can now blur your background in the newly designed call view" : "- Ora puoi sfocare lo sfondo nella nuova vista delle chiamate",
    "- Moderators can now assign general and individual permissions to participants" : "- I moderatori ora possono assegnare ai partecipanti autorizzazioni generali e individuali",
    "- You can now react to chat messages" : "- Ora puoi reagire ai messaggi della chat",
    "- In the sidebar you can now find an overview of the latest shared items" : "Nella barra laterale ora puoi trovare una panoramica degli ultimi elementi condivisi",
    "- Use a poll to collect the opinions of others or settle on a date" : "- Utilizza un sondaggio per raccogliere le opinioni degli altri o fissare una data.",
    "- Configure an expiration time for chat messages" : "- Configura un tempo di scadenza per i messaggi di chat",
    "- Start calls without notifying others in big conversations. You can send individual call notifications once the call has started." : "- Avvia le chiamate senza avvisare gli altri partecipanti alle conversazioni di gruppo. Una volta avviata la chiamata, puoi inviare notifiche individuali.",
    "- Send chat messages without notifying the recipients in case it is not urgent" : "- Invia messaggi di chat senza notificare i destinatari nel caso in cui non sia urgente",
    "- Emojis can now be autocompleted by typing a \":\"" : "- Ora è possibile completare automaticamente le emoji digitando \":\"",
    "- Link various items using the new smart-picker by typing a \"/\"" : "- Collega vari elementi utilizzando il nuovo selettore intelligente digitando un \"/\"",
    "- Moderators can now create breakout rooms (requires the High-performance backend)" : "- I moderatori possono ora creare stanze di discussione (richiede il backend ad alte prestazioni)",
    "- Calls can now be recorded (requires the High-performance backend)" : "- Ora è possibile registrare le chiamate (richiede il backend ad alte prestazioni)",
    "- Conversations can now have an avatar or emoji as icon" : "- Le conversazioni ora possono avere un avatar o un'emoji come icona.",
    "- Virtual backgrounds are now available in addition to the blurred background in video calls" : "- Oltre allo sfondo sfocato nelle videochiamate, ora sono disponibili anche sfondi virtuali.",
    "- Reactions are now available during calls" : "- Le reazioni sono ora disponibili durante le chiamate",
    "- Typing indicators show which users are currently typing a message" : "- Gli indicatori di digitazione mostrano quali utenti stanno digitando un messaggio",
    "- Groups can now be mentioned in chats" : "- Ora è possibile menzionare i gruppi nelle chat",
    "- Call recordings are automatically transcribed if a transcription provider app is registered" : "- Le registrazioni delle chiamate vengono trascritte automaticamente se è registrata un'applicazione di trascrizione.",
    "- Chat messages can be translated if a translation provider app is registered" : "- I messaggi di chat possono essere tradotti se è registrata un'applicazione di un fornitore di traduzioni.",
    "- **Markdown** can now be used in _chat_ messages" : "- **Markdown** può ora essere utilizzato nei messaggi di _chat_",
    "- Webhooks are now available to implement bots. See the documentation for more information https://nextcloud-talk.readthedocs.io/en/latest/bot-list/" : "- Webhooks sono ora disponibili per implementare bot. Consulta la documentazione per ulteriori informazioni https://nextcloud-talk.readthedocs.io/en/latest/bot-list/",
    "- Set a reminder on a chat message to be notified later again" : "- Imposta un promemoria su un messaggio di chat per ricevere nuovamente una notifica in un secondo momento",
    "- Use the **Note to self** conversation to take notes and share information between your devices" : "- Utilizza la conversazione **Nota a me stesso** per prendere appunti e condividere informazioni tra i tuoi dispositivi",
    "- Captions allow to send a message with a file at the same time" : "- Le didascalie consentono di inviare un messaggio insieme a un file.",
    "- Video of the speaker is now visible while sharing the screen and call reactions are animated" : "- Il video di chi sta parlando è ora visibile durante la condivisione dello schermo e le reazioni alle chiamate sono animate.",
    "- Messages can now be edited by logged-in authors and moderators for 6 hours" : "- I messaggi possono ora essere modificati dagli autori e dai moderatori per 6 ore.",
    "- Unsent message drafts are now saved in your browser" : "- Le bozze dei messaggi non inviati ora vengono salvate nel browser.",
    "- Text chatting can now be done in a federated way with other Talk servers" : "- La chat di testo può ora essere effettuata in modo federato con altri server Talk.",
    "- Moderators can now ban accounts and guests to prevent them from rejoining a conversation" : "- I moderatori possono ora bandire account e ospiti per impedire loro di partecipare nuovamente a una conversazione.",
    "- Upcoming calls from linked calendar events and out-of-office replacements are now shown in conversations" : "- Le chiamate in arrivo dagli eventi del calendario collegati e dai sostituti per assenza vengono ora visualizzate nelle conversazioni.",
    "- Calls can now be done in a federated way with other Talk servers (requires the High-performance backend)" : "- Le chiamate possono ora essere effettuate in modo federato con altri server Talk (richiede il backend ad alte prestazioni)",
    "- Introducing the Nextcloud Talk desktop client for Windows, macOS and Linux: %s" : "- Presentiamo il client desktop Nextcloud Talk per Windows, macOS e Linux: %s",
    "- Summarize call recordings and unread messages in chats with the Nextcloud Assistant" : "- Riassumi le registrazioni delle chiamate e i messaggi non letti nelle chat con Nextcloud Assistant",
    "- Improved meetings with recognizing guests invited via their email address, import of participant lists, drafts for polls and downloading call participant lists" : "- Miglioramento delle riunioni con il riconoscimento degli ospiti invitati tramite il loro indirizzo e-mail, l'importazione degli elenchi dei partecipanti, le bozze per i sondaggi e il download degli elenchi dei partecipanti alle chiamate.",
    "- Archive conversations to stay focused" : "- Archivia le conversazioni per rimanere concentrato",
    "- Schedule a meeting into your calendar from within a conversation" : "- Pianifica un meeting nel tuo calendario direttamente dalla conversazione",
    "- Search for messages of the current conversation directly in the right sidebar" : "- Cerca i messaggi della conversazione corrente direttamente nella barra laterale destra",
    "- See more conversations on a first glance with the new compact list (enable in the Talk settings)" : "- Visualizza più conversazioni a colpo d'occhio con il nuovo elenco compatto (abilita nelle impostazioni di Talk)",
    "- Meeting conversations now sync the title and description from the calendar and are hidden with a search filter until they are close to the start" : "- Le conversazioni delle riunioni ora sincronizzano il titolo e la descrizione dal calendario e vengono nascoste con un filtro di ricerca fino a quando non si avvicina l'ora di inizio.",
    "- Mark conversations as sensitive in the notification settings, to hide the message content from the conversation list and notifications" : "- Contrassegna le conversazioni come sensibili nelle impostazioni di notifica, per nascondere il contenuto dei messaggi dall'elenco delle conversazioni e dalle notifiche.",
    "- To receive push notifications during \"Do not disturb\", mark conversations as important" : "- Per ricevere notifiche push durante la modalità “Non disturbare”, contrassegna le conversazioni come importanti.",
    "- Add other participants to a one-to-one call to create a new group call on the fly" : "- Aggiungi altri partecipanti a una chiamata individuale per creare una nuova chiamata di gruppo al volo",
    "- Use threads to keep your chat and discussions organized" : "- Usa gli argomenti per mantenere organizzate le tue chat e discussioni",
    "- Live transcriptions now available during the call (requires the live-transcription ExApp and the High-performance backend)" : "- Trascrizioni in tempo reale ora disponibili durante la chiamata (richiede l'ExApp per la trascrizione in tempo reale e il backend ad alte prestazioni)",
    "_All %n participant_::_All %n participants_" : ["Tutti i %n partecipanti","Tutti i %n partecipanti","Tutti i %n partecipanti"],
    "Talk updates ✅" : "Aggiornamenti di Talk ✅",
    "Reaction deleted by author" : "Reazione eliminata dall'autore",
    "{actor} created the conversation" : "{actor} ha creato la conversazione",
    "You created the conversation" : "Hai creato la conversazione",
    "System created the conversation" : "Il sistema ha creato la conversazione",
    "An administrator created the conversation" : "Un amministratore ha creato la conversazione",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} ha rinominato la conversazione da \"%1$s\" a \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Hai rinominato la conversazione da \"%1$s\" a \"%2$s\"",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Un amministratore ha rinominato la conversazione da \"%1$s\" a \"%2$s\"",
    "{actor} set the description" : "{actor} ha impostato la descrizione",
    "You set the description" : "Hai impostato la descrizione",
    "An administrator set the description" : "Un amministratore ha impostato la descrizione",
    "{actor} removed the description" : "{actor} ha rimosso la descrizione",
    "You removed the description" : "Hai rimosso la descrizione",
    "An administrator removed the description" : "Un amministratore ha rimosso la descrizione",
    "You started a silent call" : "Hai avviato una chiamata silenziosa",
    "Outgoing silent call" : "Chiamata silenziosa in uscita",
    "{actor} started a silent call" : "{actor} ha avviato una chiamata silenziosa ",
    "Incoming silent call" : "Chiamata silenziosa in arrivo",
    "You started a call" : "Hai iniziato una chiamata",
    "Outgoing call" : "Chiamata in uscita",
    "{actor} started a call" : "{actor} ha iniziato una chiamata",
    "Incoming call" : "Chiamata in arrivo",
    "{actor} joined the call" : "{actor} si è unito alla chiamata",
    "You joined the call" : "Ti sei unito alla chiamata",
    "{actor} left the call" : "{actor} ha abbandonato la chiamata",
    "You left the call" : "Hai abbandonato la chiamata",
    "{actor} unlocked the conversation" : "{actor} ha sbloccato la conversazione",
    "You unlocked the conversation" : "Hai sbloccato la conversazione",
    "An administrator unlocked the conversation" : "Un amministratore ha sbloccato la conversazione",
    "{actor} locked the conversation" : "{actor} ha bloccato la conversazione",
    "You locked the conversation" : "Hai bloccato la conversazione",
    "An administrator locked the conversation" : "Un amministratore ha bloccato la conversazione",
    "{actor} limited the conversation to the current participants" : "{actor} ha ristretto la conversazione ai partecipanti attuali",
    "You limited the conversation to the current participants" : "Hai ristretto la conversazione ai partecipanti attuali",
    "An administrator limited the conversation to the current participants" : "Un amministratore ha ristretto la conversazione ai partecipanti attuali",
    "{actor} opened the conversation to registered users" : "{actor} ha aperto la conversazione agli utenti registrati",
    "You opened the conversation to registered users" : "Hai aperto la conversazione agli utenti registrati",
    "An administrator opened the conversation to registered users" : "Un amministratore ha aperto la conversazione agli utenti registrati",
    "{actor} opened the conversation to registered users and users created with the Guests app" : "{actor} ha aperto la conversazione agli utenti registrati e agli utenti creati con l'applicazione Ospiti",
    "You opened the conversation to registered users and users created with the Guests app" : "Hai aperto la conversazione agli utenti registrati e agli utenti creati con l'applicazione Ospiti",
    "An administrator opened the conversation to registered users and users created with the Guests app" : "Un amministratore ha aperto la conversazione agli utenti registrati e agli utenti creati con l'applicazione Ospiti",
    "The conversation is now open to everyone" : "La conversazione è ora aperta a chiunque",
    "{actor} opened the conversation to everyone" : "{actor} ha aperto la conversazione a chiunque",
    "You opened the conversation to everyone" : "Hai aperto la conversazione a chiunque",
    "{actor} restricted the conversation to moderators" : "{actor} ha ristretto la conversazione ai moderatori",
    "You restricted the conversation to moderators" : "Hai ristretto la conversazione ai moderatori",
    "{actor} started breakout rooms" : "{actor} ha avviato le sessioni secondarie  ",
    "You started breakout rooms" : "Hai avviato le sessioni secondarie",
    "{actor} stopped breakout rooms" : "{actor} ha interrotto le sessioni secondarie ",
    "You stopped breakout rooms" : "Hai interrotto le sessioni secondarie",
    "{actor} allowed guests" : "{actor} ha permesso gli ospiti",
    "You allowed guests" : "Hai permesso gli ospiti",
    "An administrator allowed guests" : "Un amministratore ha consentito gli ospiti",
    "{actor} disallowed guests" : "{actor} ha vietato gli ospiti",
    "You disallowed guests" : "Hai vietato gli ospiti",
    "An administrator disallowed guests" : "Un amministratore ha vietato gli ospiti",
    "{actor} set a password" : "{actor} ha impostato una password",
    "You set a password" : "Hai impostato una password",
    "An administrator set a password" : "Un amministratore ha impostato una password",
    "{actor} removed the password" : "{actor} ha rimosso la password",
    "You removed the password" : "Hai rimosso la password",
    "An administrator removed the password" : "Un amministratore ha rimosso la password",
    "{actor} added {user}" : "{actor} ha aggiunto {user}",
    "You joined the conversation" : "Ti sei unito alla conversazione",
    "{actor} joined the conversation" : "{actor} si è unito alla conversazione",
    "You added {user}" : "Hai aggiunto {user}",
    "{actor} added you" : "{actor} ti ha aggiunto",
    "An administrator added you" : "Un amministratore ti ha aggiunto",
    "An administrator added {user}" : "Un amministratore ha aggiunto {user}",
    "You left the conversation" : "Hai abbandonato la conversazione",
    "{actor} left the conversation" : "{actor} ha abbandonato la conversazione",
    "{actor} removed {user}" : "{actor} ha rimosso {user}",
    "You removed {user}" : "Hai rimosso {user}",
    "{actor} removed you" : "{actor} ti ha rimosso",
    "An administrator removed you" : "Un amministratore ti ha rimosso",
    "An administrator removed {user}" : "Un amministratore ha rimosso {user}",
    "{actor} invited {federated_user}" : "{actor} ha invitato {federated_user}",
    "You invited {federated_user}" : "Hai invitato {federated_user}",
    "You accepted the invitation" : "Hai accettato l'invito",
    "{actor} invited you" : "{actor} ti ha invitato",
    "An administrator invited you" : "Un amministratore ti ha invitato",
    "An administrator invited {federated_user}" : "Un amministratore ha invitato {federated_user}",
    "{federated_user} accepted the invitation" : "{federated_user} ha accettato l'invito",
    "{actor} removed {federated_user}" : "{actor} ha rimosso {federated_user}",
    "You removed {federated_user}" : "Hai rimosso {federated_user}",
    "You declined the invitation" : "Hai rifiutato l'invito",
    "An administrator removed {federated_user}" : "Un amministratore ha rimosso {federated_user}",
    "{federated_user} declined the invitation" : "{federated_user} ha rifiutato l'invito",
    "{actor} added group {group}" : "{actor} ha aggiunto il gruppo {group}",
    "You added group {group}" : "Hai aggiunto il gruppo {group}",
    "An administrator added group {group}" : "Un amministratore ha aggiunto il gruppo {group}",
    "{actor} removed group {group}" : "{actor} ha rimosso il gruppo {group}",
    "You removed group {group}" : "Hai rimosso il gruppo {group}",
    "An administrator removed group {group}" : "Un amministratore ha rimosso il gruppo {group}",
    "{actor} added team {circle}" : "{actor} ha aggiunto il team {circle}",
    "You added team {circle}" : "Hai aggiunto il team {circle}",
    "An administrator added team {circle}" : "Un amministratore ha aggiunto il team {circle}",
    "{actor} removed team {circle}" : "{actor} ha rimosso il team {circle}",
    "You removed team {circle}" : "Hai rimosso il team {circle}",
    "An administrator removed team {circle}" : "Un amministratore ha rimosso il team {circle}",
    "{actor} added {phone}" : "{actor} ha aggiunto {phone}",
    "You added {phone}" : "Hai aggiunto {phone}",
    "An administrator added {phone}" : "Un amministratore ha aggiunto {phone}",
    "{actor} removed {phone}" : "{actor} ha rimosso {phone}",
    "You removed {phone}" : "Hai rimosso {phone}",
    "An administrator removed {phone}" : "Un amministratore ha rimosso {phone}",
    "{actor} promoted {user} to moderator" : "{actor} ha promosso {user} a moderatore",
    "You promoted {user} to moderator" : "Hai promosso {user} a moderatore",
    "{actor} promoted you to moderator" : "{actor} ti ha promosso a moderatore",
    "An administrator promoted you to moderator" : "Un amministratore ti ha promosso a moderatore",
    "An administrator promoted {user} to moderator" : "Un amministratore ha promosso {user} a moderatore",
    "{actor} demoted {user} from moderator" : "{actor} ha rimosso {user} da moderatore",
    "You demoted {user} from moderator" : "Hai rimosso {user} da moderatore",
    "{actor} demoted you from moderator" : "{actor} ti ha rimosso da moderatore",
    "An administrator demoted you from moderator" : "Un amministratore ti ha rimosso da moderatore",
    "An administrator demoted {user} from moderator" : "Un amministratore ha rimosso {user} da moderatore",
    "{actor} shared a file which is no longer available" : "{actor} ha condiviso un file che non è più disponibile",
    "You shared a file which is no longer available" : "Hai condiviso un file che non è più disponibile",
    "File shares are currently not supported in federated conversations" : "La condivisione dei file non è al momento supportata nelle conversazioni federate",
    "The shared location is malformed" : "La posizione condivisa è errata",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} ha configurato Matterbridge per sincronizzare questa conversazione con altre chat",
    "You set up Matterbridge to synchronize this conversation with other chats" : "Hai configurato Matterbridge per sincronizzare questa conversazione con altre chat",
    "{actor} created thread {title}" : "{actor} ha creato l'argomento {title}",
    "You created thread {title}" : "Hai creato l'argomento {title}",
    "{actor} renamed thread {title}" : "{actor} ha rinominato l'argomento {title}",
    "You renamed thread {title}" : "Hai rinominato l'argomento {title}",
    "{actor} updated the Matterbridge configuration" : "{actor} ha aggiornato la configurazione di Matterbridge",
    "You updated the Matterbridge configuration" : "Hai aggiornato la configurazione di Matterbridge",
    "{actor} removed the Matterbridge configuration" : "{actor} ha rimosso la configurazione di Matterbridge",
    "You removed the Matterbridge configuration" : "Hai rimosso la configurazione di Matterbridge",
    "{actor} started Matterbridge" : "{actor} ha avviato Matterbridge",
    "You started Matterbridge" : "Hai avviato Matterbridge",
    "{actor} stopped Matterbridge" : "{actor} ha fermato Matterbridge",
    "You stopped Matterbridge" : "Hai fermato Matterbridge",
    "{actor} deleted a message" : "{actor} ha eliminato un messaggio",
    "You deleted a message" : "Hai eliminato un messaggio",
    "{actor} edited a message" : "{actor} ha modificato il messaggio",
    "You edited a message" : "Hai modificato il messaggio",
    "{actor} deleted a reaction" : "{actor} ha eliminato una reazione",
    "You deleted a reaction" : "Hai eliminato una reazione",
    "_You set the message expiration to %n week_::_You set the message expiration to %n weeks_" : ["Hai impostato la scadenza dei messaggi in %n settimana","Hai impostato la scadenza dei messaggi in %n settimane","Hai impostato la scadenza dei messaggi in %n settimane"],
    "_You set the message expiration to %n day_::_You set the message expiration to %n days_" : ["Hai impostato la scadenza dei messaggi in %n giorno","Hai impostato la scadenza dei messaggi in %n giorni","Hai impostato la scadenza dei messaggi in %n giorni"],
    "_You set the message expiration to %n hour_::_You set the message expiration to %n hours_" : ["Hai impostato la scadenza dei messaggi in %n ora","Hai impostato la scadenza dei messaggi in %n ore","Hai impostato la scadenza dei messaggi in %n ore"],
    "_You set the message expiration to %n minute_::_You set the message expiration to %n minutes_" : ["Hai impostato la scadenza dei messaggi in %n minuto","Hai impostato la scadenza dei messaggi in %n minuti","Hai impostato la scadenza dei messaggi in %n minuti"],
    "_{actor} set the message expiration to %n week_::_{actor} set the message expiration to %n weeks_" : ["{actor} ha impostato la scadenza dei messaggi in %n settimana","{actor} ha impostato la scadenza dei messaggi in %n settimane","{actor} ha impostato la scadenza dei messaggi in %n settimane"],
    "_{actor} set the message expiration to %n day_::_{actor} set the message expiration to %n days_" : ["{actor} ha impostato la scadenza dei messaggi in %n giorno","{actor} ha impostato la scadenza dei messaggi in %n giorni","{actor} ha impostato la scadenza dei messaggi in %n giorni"],
    "_{actor} set the message expiration to %n hour_::_{actor} set the message expiration to %n hours_" : ["{actor} ha impostato la scadenza dei messaggi in %n ora","{actor} ha impostato la scadenza dei messaggi in %n ore","{actor} ha impostato la scadenza dei messaggi in %n ore"],
    "_{actor} set the message expiration to %n minute_::_{actor} set the message expiration to %n minutes_" : ["{actor} ha impostato la scadenza dei messaggi in %n minuto","{actor} ha impostato la scadenza dei messaggi in %n minuti","{actor} ha impostato la scadenza dei messaggi in %n minuti"],
    "{actor} disabled message expiration" : "{actor} ha disattivato la scadenza dei messaggi ",
    "You disabled message expiration" : "Hai disattivato la scadenza dei messaggi",
    "{actor} cleared the history of the conversation" : "{actor} ha cancellato la cronologia della conversazione",
    "You cleared the history of the conversation" : "Hai cancellato la cronologia della conversazione",
    "{actor} set the conversation picture" : "{actor} ha impostato l'icona della conversazione",
    "You set the conversation picture" : "Hai impostato l'icona della conversazione",
    "{actor} removed the conversation picture" : "{actor} ha rimosso l'icona della conversazione",
    "You removed the conversation picture" : "Hai rimosso l'immagine della conversazione",
    "{actor} ended the poll {poll}" : "{actor} ha concluso il sondaggio {poll}",
    "You ended the poll {poll}" : "Hai concluso il sondaggio {poll}",
    "{actor} started the video recording" : "{actor} ha avviato la registrazione video",
    "You started the video recording" : "Hai avviato la registrazione video",
    "{actor} stopped the video recording" : "{actor} ha interrotto la registrazione video",
    "You stopped the video recording" : "Hai interrotto la registrazione video",
    "{actor} started the audio recording" : "{actor} ha avviato la registrazione audio",
    "You started the audio recording" : "Hai avviato la registrazione audio",
    "{actor} stopped the audio recording" : "{actor} ha interrotto la registrazione audio",
    "You stopped the audio recording" : "Hai interrotto la registrazione audio",
    "The recording failed" : "La registrazione non è riuscita",
    "Someone voted on the poll {poll}" : "Qualcuno ha votato nel sondaggio {poll}",
    "Message deleted by author" : "Messaggio eliminato dall'autore",
    "Message deleted by {actor}" : "Messaggio eliminato da {actor}",
    "Message deleted by you" : "Messaggio eliminato da te",
    "Deleted user" : "Utente eliminato",
    "Unknown number" : "Numero sconosciuto",
    "Administration" : "Amministrazione",
    "System" : "Sistema",
    "%s (guest)" : "%s (ospite)",
    "Missed call" : "Chiamata persa",
    "Unanswered call" : "Chiamata non risposta",
    "Call ended (Duration {duration})" : "Chiamata terminata (Durata {duration}) ",
    "Call was ended, as it reached the maximum call duration (Duration {duration})" : "La chiamata è stata terminata in quanto ha raggiunto la massima durata per le chiamate (Durata {duration})",
    "{actor} ended the call (Duration {duration})" : "{actor} ha terminato la chiamata (Durata {duration})",
    "_Call with %n guest was ended, as it reached the maximum call duration (Duration {duration})_::_Call with %n guests was ended, as it reached the maximum call duration (Duration {duration})_" : ["La chiamata con %n ospite è terminata, in quanto ha raggiunto la massima durata per le chiamate (Durata {duration})","La chiamata con %n ospiti è terminata, in quanto ha raggiunto la massima durata per le chiamate (Durata {duration})","La chiamata con %n ospiti è terminata, in quanto ha raggiunto la massima durata per le chiamate (Durata {duration})"],
    "_Call with %n guest ended (Duration {duration})_::_Call with %n guests ended (Duration {duration})_" : ["La chiamata con %n ospite è terminata (Durata {duration})","La chiamata con %n ospiti è terminata (Durata {duration})","La chiamata con %n ospiti è terminata (Durata {duration})"],
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} ha terminato la chiamata con %n ospite (Durata {duration})","{actor} ha terminato la chiamata con %n ospiti (Durata {duration})","{actor} ha terminato la chiamata con %n ospiti (Durata {duration})"],
    "Call with {user1} was ended, as it reached the maximum call duration (Duration {duration})" : "La chiamata con {user1} è terminata, in quanto ha raggiunto la massima durata per le chiamate (Durata {duration})",
    "Call with {user1} ended (Duration {duration})" : "La chiamata con {user1} è terminata (Durata {duration})",
    "{actor} ended the call with {user1} (Duration {duration})" : "{actor} ha terminato la chiamata con {user1} ospite (Durata {duration})",
    "Call with {user1} and {user2} was ended, as it reached the maximum call duration (Duration {duration})" : "La chiamata con {user1} e {user2} è terminata, in quanto ha raggiunto la massima durata per le chiamate (Durata {duration})",
    "Call with {user1} and {user2} ended (Duration {duration})" : "La chiamata con {user1} e {user2} è terminata (Durata {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} ha terminato la chiamata con {user1} e {user2} (Durata {duration})",
    "Call with {user1}, {user2} and {user3} was ended, as it reached the maximum call duration (Duration {duration})" : "La chiamata con {user1}, {user2} e {user3} è terminata, in quanto ha raggiunto la massima durata per le chiamate (Durata {duration})",
    "Call with {user1}, {user2} and {user3} ended (Duration {duration})" : "La chiamata con {user1}, {user2} e {user3} è terminata (Durata {duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} ha terminato la chiamata con {user1}, {user2} e {user3} (Durata {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} was ended, as it reached the maximum call duration (Duration {duration})" : "La chiamata con {user1}, {user2}, {user3} e {user4} è terminata, in quanto ha raggiunto la massima durata per le chiamate (Durata {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} ended (Duration {duration})" : "La chiamata con {user1}, {user2}, {user3} e {user4} è terminata (Durata {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} ha terminato la chiamata con {user1}, {user2}, {user3} e {user4} (Durata {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} was ended, as it reached the maximum call duration (Duration {duration})" : "La chiamata con {user1}, {user2}, {user3}, {user4} e {user5} è terminata, in quanto ha raggiunto la massima durata per le chiamate (Durata {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} ended (Duration {duration})" : "La chiamata con {user1}, {user2}, {user3}, {user4} e {user5} è terminata (Durata {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} ha terminato la chiamata con {user1}, {user2}, {user3}, {user4} e {user5} (Durata {duration})",
    "Message of {user} in {conversation}" : "Messaggio di {user} in {conversation}",
    "Message of {user}" : "Messaggio di {user}",
    "Message of a deleted user in {conversation}" : "Messaggio di un utente eliminato in {conversation}",
    "Talk conversations" : "Conversazioni di Talk",
    "Talk to %s" : "Parla con %s",
    "An error occurred. Please contact your administrator." : "Si è verificato un errore. Per favore, contatta il tuo amministratore.",
    "Storage quota exceeded" : "Quota di archiviazione superata",
    "File not found" : "File non trovato",
    "File is not shared, or shared but not with the user" : "Il file non è condiviso, o condiviso ma non con l'utente",
    "No account available to delete." : "Nessun account disponibile da eliminare.",
    "Poll" : "Sondaggio",
    "Password needs to be set" : "Bisogna impostare una password",
    "Uploading the file failed" : "Il caricamento del file è fallito",
    "No image file provided" : "Nessun file immagine fornito",
    "File is too big" : "Il file è troppo grande",
    "Invalid file provided" : "File fornito non valido",
    "Invalid image" : "Immagine non valida ",
    "Unknown filetype" : "Tipo di file sconosciuto ",
    "Talk mentions" : "Menzioni di Talk",
    "More conversations" : "Più conversazioni",
    "Say hi to your friends and colleagues!" : "Saluta i tuoi amici e i tuoi colleghi!",
    "No unread mentions" : "Nessuna menzione non letta",
    "Call in progress" : "Chiamata in corso",
    "You were mentioned" : "Sei stato menzionato",
    "Write to conversation" : "Scrivi nella conversazione",
    "Writes event information into a conversation of your choice" : "Scrive le informazioni di evento in una conversazione di tua scelta",
    "Missing email field in header line" : "Indirizzo email mancante nell'intestazione",
    "Following lines are invalid: %s" : "Le seguenti linee non sono valide: %s",
    "%1$s invited you to conversation \"%2$s\"." : "%1$s ti ha invitato nella conversazione \"%2$s\".",
    "You were invited to conversation \"%s\"." : "Hai ricevuto un invito per la conversazione \"%s\".",
    "Conversation invitation" : "Inviti di conversazione",
    "Scheduled time" : "Orario programmato",
    "Description" : "Descrizione",
    "You can also dial-in via phone with the following details" : "Puoi accedere anche tramite telefono con i seguenti dettagli",
    "Dial-in information" : "Informazioni di accesso",
    "Meeting ID" : "ID riunione",
    "Your PIN" : "Il tuo PIN",
    "Click the button below to join the lobby now." : "Premi il bottone in basso per entrare nella stanza ora.",
    "Click the link below to join the lobby now." : "Premi il collegamento in basso per entrare nella stanza adesso.",
    "Join lobby for \"%s\"" : "Entra nella stanza per \"%s\"",
    "Click the button below to join the conversation now." : "Premi il bottone in basso per entrare nella conversazione ora.",
    "Click the link below to join the conversation now." : "Premi il collegamento in basso per entrare nella conversazione ora.",
    "Join \"%s\"" : "Entra in \"%s\"",
    "Meeting" : "Riunione",
    "Password request: %s" : "Password richiesta: %s",
    "Private conversation" : "Conversazione privata",
    "Deleted user (%s)" : "Utente eliminato (%s)",
    "Failed to upload call recording" : "Caricamento della registrazione della chiamata fallita",
    "The recording server failed to upload recording of call {call}. Please reach out to the administration." : "Il server di registrazione ha fallito il caricamento della chiamata {call}. Per favore, contatta un amministratore.",
    "Dismiss notification" : "Cancella notifica",
    "Call recording now available" : "Registrazione della chiamata ora disponibile",
    "The recording for the call in {call} was uploaded to {file}." : "La registrazione della chiamata in {call} è stata caricata su {file}.",
    "Transcript now available" : "Trascrizione ora disponibile",
    "The transcript for the call in {call} was uploaded to {file}." : "Trascrizione della chiamata in {call} è stata caricata in {file}.",
    "Failed to transcript call recording" : "Impossibile trascrivere la registrazione della chiamata",
    "The server failed to transcript the recording at {file} for the call in {call}. Please reach out to the administration." : "Il server ha fallito la trascrizione della registrazione nel file {file} per la chiamata {call}. Per favore, contatta un amministratore.",
    "Call summary now available" : "Riassunto della chiamata ora disponibile",
    "The summary for the call in {call} was uploaded to {file}." : "Il riassunto per la chiamata {call} è stato caricato su {file}. ",
    "Failed to summarize call recording" : "Impossibile riassumere la registrazione della chiamata",
    "The server failed to summarize the recording at {file} for the call in {call}. Please reach out to the administration." : "Il server ha fallito il riassunto della registrazione del file {file} per la chiamata in {call}. Contatta un amministratore.",
    "{user1} invited you to join {roomName} on {remoteServer}" : "{user1} ti ha invitato ad entrare nella stanza {roomName} su {remoteServer}",
    "Accept" : "Accetta",
    "Decline" : "Rifiuta",
    "{user1} invited you to a federated conversation" : "{user1} ti ha invitato in una conversazione federata",
    "Someone reacted" : "Qualcuno ti ha contattato",
    "New message" : "Nuovo messaggio",
    "Reminder" : "Promemoria",
    "Someone mentioned you" : "Qualcuno ti ha menzionato",
    "Notification" : "Notifica",
    "Someone reacted in a private conversation" : "Qualcuno ha reagito in una conversazione privata",
    "You received a message in a private conversation" : "Hai ricevuto un messaggio in una conversazione privata",
    "Reminder in a private conversation" : "Promemoria in una conversazione privata",
    "Someone mentioned you in a private conversation" : "Qualcuno ti ha menzionato in una conversazione privata",
    "Notification in a private conversation" : "Notifica in una conversazione privata",
    "Reminder: You in {call}" : "Promemoria: Te stesso in {call}",
    "Reminder: {user} in {call}" : "Promemoria: {user} in {call}",
    "Reminder: Deleted user in {call}" : "Promemoria: Utente eliminato in {call}",
    "Reminder: {guest} (guest) in {call}" : "Promemoria: {guest} (ospite) in {call}",
    "Reminder: Guest in {call}" : "Promemoria: Ospite in {call}",
    "{user} reacted with {reaction}" : "{user} ha reagito con {reaction}",
    "{user} reacted with {reaction} in {call}" : "{user} ha reagito con {reaction} in {call}",
    "Deleted user reacted with {reaction} in {call}" : "L'utente eliminato ha reagito con {reaction} in {call}",
    "{guest} (guest) reacted with {reaction} in {call}" : "{guest} (ospite) ha reagito con {reaction} in {call}",
    "Guest reacted with {reaction} in {call}" : "Ospite ha reagito con {reaction} in {call}",
    "{user} in {call}" : "{user} in {call}",
    "Deleted user in {call}" : "Utente eliminato in {call}",
    "{guest} (guest) in {call}" : "{guest} (guest) in {call}",
    "Guest in {call}" : "Ospite in {call}",
    "{user} sent you a private message" : "{user} ti ha inviato un messaggio privato",
    "{user} sent a message in conversation {call}" : "{user} ha inviato un messaggio nella conversazione {call}",
    "A deleted user sent a message in conversation {call}" : "Un utente eliminato ha inviato un messaggio nella conversazione {call}",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (ospite) ha inviato un messaggio nella conversazione {call}",
    "A guest sent a message in conversation {call}" : "Un ospite ha inviato un messaggio nella conversazione {call}",
    "{user} replied to your private message" : "{user} ha risposto al tuo messaggio privato",
    "{user} replied to your message in conversation {call}" : "{user} ha risposto al tuo messaggio nella conversazione {call}",
    "A deleted user replied to your message in conversation {call}" : "Un utente eliminato ha risposto al tuo messaggio nella conversazione {call}",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (ospite) ha risposto al tuo messaggio nella conversazione {call}",
    "A guest replied to your message in conversation {call}" : "Un ospite ha risposto al tuo messaggio nella conversazione {call}",
    "Reminder: You in private conversation {call}" : "Promemoria: Te stesso nella conversazione privata {call}",
    "Reminder: A deleted user in private conversation {call}" : "Promemoria: Un utente eliminato nella conversazione privata {call}",
    "Reminder: {user} in private conversation" : "Promemoria: {user} in una conversazione privata",
    "Reminder: You in conversation {call}" : "Promemoria: Te stesso nella conversazione {call}",
    "Reminder: {user} in conversation {call}" : "Promemoria: {user} nella conversazione {call}",
    "Reminder: A deleted user in conversation {call}" : "Promemoria: Un utente eliminato nella conversazione {call}",
    "Reminder: {guest} (guest) in conversation {call}" : "Promemoria: {guest} (ospite) nella conversazione {call}",
    "Reminder: A guest in conversation {call}" : "Promemoria: Un ospite nella conversazione {call}",
    "{user} reacted with {reaction} to your private message" : "{user} ha reagito con {reaction} al tuo messaggio privato",
    "{user} reacted with {reaction} to your message in conversation {call}" : "{user} ha reagito con {reaction} al tuo messaggio nella conversazione {call}",
    "A deleted user reacted with {reaction} to your message in conversation {call}" : "Un utente eliminato ha reagito con {reaction} al tuo messaggio nella conversazione {call}",
    "{guest} (guest) reacted with {reaction} to your message in conversation {call}" : "{guest} (guest) ha reagito con {reaction} al tuo messaggio nella conversazione {call}",
    "A guest reacted with {reaction} to your message in conversation {call}" : "Un ospite ha reagito con {reaction} al tuo messaggio nella conversazione {call}",
    "{user} mentioned you in a private conversation" : "{user} ti ha menzionato in una conversazione privata",
    "{user} mentioned group {group} in conversation {call}" : "{user} ha menzionato il gruppo {group} nella conversazione {call}",
    "{user} mentioned team {team} in conversation {call}" : "{user} ha menzionato il team {team} nella conversazione {call}",
    "{user} mentioned everyone in conversation {call}" : "{user} ha menzionato chiunque nella conversazione {call}",
    "{user} mentioned you in conversation {call}" : "{user} ti ha menzionato nella conversazione {call}",
    "A deleted user mentioned group {group} in conversation {call}" : "Un utente eliminato ha menzionato il gruppo {group} nella conversazione {call}",
    "A deleted user mentioned team {team} in conversation {call}" : "Un utente eliminato ha menzionato il team {team} nella conversazione {call}",
    "A deleted user mentioned everyone in conversation {call}" : "Un utente eliminato ha menzionato chiunque nella conversazione {call}",
    "A deleted user mentioned you in conversation {call}" : "Un utente eliminato ti ha menzionato nella conversazione {call}",
    "{guest} (guest) mentioned group {group} in conversation {call}" : "{guest} (ospite) ha menzionato il gruppo {group} nella conversazione {call}",
    "{guest} (guest) mentioned team {team} in conversation {call}" : "{guest} (ospite) ha menzionato il team {team} nella conversazione {call}",
    "{guest} (guest) mentioned everyone in conversation {call}" : "{guest} (ospite) ha menzionato chiunque nella conversazione {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (ospite) ti ha menzionato nella conversazione {call}",
    "A guest mentioned group {group} in conversation {call}" : "Un ospite ha menzionato il gruppo {group} nella conversazione {call}",
    "A guest mentioned team {team} in conversation {call}" : "Un ospite ha menzionato il team {team} nella conversazione {call}",
    "A guest mentioned everyone in conversation {call}" : "Un ospite ha menzionato chiunque nella conversazione {call}",
    "A guest mentioned you in conversation {call}" : "Un ospite ti ha menzionato nella conversazione {call}",
    "View message" : "Vedi messaggio",
    "Dismiss reminder" : "Rimuovi promemoria",
    "View chat" : "Visualizza chat",
    "{user} invited you to a group conversation: {call}" : "{user} ti ha invitato a una conversazione di gruppo: {call}",
    "Join call" : "Unisciti alla chiamata",
    "Answer call" : "Rispondi alla chiamata",
    "{user} would like to talk with you" : "{user} vorrebbe parlare con te",
    "Call back" : "Richiama",
    "You missed a call from {user}" : "Hai perso una chiamata da {user}",
    "Accept call" : "Accetta chiamata",
    "Incoming phone call from {call}" : "Chiamata telefonica in arrivo da {call}",
    "You missed a phone call from {call}" : "Hai una chiamata telefonica persa da {call}",
    "A group call has started in {call}" : "Una chiamata di gruppo è iniziata in {call}",
    "You missed a group call in {call}" : "Hai perso una chiamata di gruppo in {call}",
    "{email} is requesting the password to access {file}" : "{email} sta richiedendo la password per accedere a {file}",
    "{email} tried to request the password to access {file}" : "{email} ha provato a richiedere la password per accedere a {file}",
    "Someone is requesting the password to access {file}" : "Qualcuno sta richiedendo la password per accedere a {file}",
    "Someone tried to request the password to access {file}" : "Qualcuno ha provato a richiedere la password per accedere a {file}",
    "Open settings" : "Apri impostazioni",
    "Hosted signaling server added" : "Server di segnalazione aggiunto",
    "The hosted signaling server is now configured and will be used." : "Il server di segnalazione ospitato è ora configurato e sarà utilizzato.",
    "Hosted signaling server removed" : "Server di segnalazione rimosso",
    "The hosted signaling server was removed and will not be used anymore." : "Il server di segnalazione ospitato è stato rimosso e non sarà più utilizzato.",
    "Hosted signaling server changed" : "Server di signaling modificato",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "L'account del server di segnalazione ospitato ha modificato lo stato da \"{oldstatus}\" a \"{newstatus}\".",
    "pending" : "in sospeso",
    "active" : "attivo",
    "expired" : "scaduto",
    "blocked" : "bloccato",
    "error" : "errore",
    "The certificate of {host} expires in {days} days" : "Il certificato di {host} scade in {days} giorni",
    "The certificate of {host} expired" : "Il certificato di {host} è scaduto",
    "Contact via Talk" : "Contatto tramite Talk",
    "Open Talk" : "Apri Talk",
    "Default" : "Predefinita",
    "Presentation" : "Presentazione",
    "Conversations" : "Conversazioni",
    "Messages in current conversation" : "Messaggi nella conversazione corrente",
    "{user}" : "{user}",
    "Messages" : "Messaggi",
    "{user} in {conversation}" : "{user} in {conversation}",
    "Messages in other conversations" : "Messaggi in altre conversazioni",
    "One-to-one rooms always need to show the other users avatar" : "Le stanze uno-ad-uno devono sempre mostrare l'avatar degli altri utenti.",
    "Invalid emoji character" : "Carattere emoji non valido",
    "Invalid background color" : "Colore di sfondo non valido",
    "Avatar image is not square" : "L'immagine personale non è quadrata",
    "Room {number}" : "Stanza {number}",
    "Other" : "Altro",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "Richiesta della prova non riuscita perché il server di prova non è raggiungibile. Ritenta più tardi.",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "Si è verificato un problema con l'autenticazione di questa istanza. Forse non è raggiungibile dall'esterno per verificare l'URL.",
    "Something unexpected happened." : "Si è verificato qualcosa di inatteso.",
    "The URL is invalid." : "L'URL non è valido.",
    "An HTTPS URL is required." : "È richiesto un URL HTTPS.",
    "The email address is invalid." : "L'indirizzo di posta non è valido.",
    "The language is invalid." : "La lingua non è valida.",
    "The country is invalid." : "La nazione non è valida.",
    "There is a problem with the request of the trial. Please check your logs for further information." : "Si è verificato un problema con la richiesta della prova. Controlla i registri per ulteriori informazioni.",
    "Too many requests are send from your servers address. Please try again later." : "Troppe richieste inviate dall'indirizzo del tuo server. Riprova più tardi.",
    "There is already a trial registered for this Nextcloud instance." : "Esiste già una versione di prova registrata per questa istanza di Nextcloud.",
    "Something unexpected happened. Please try again later." : "Si è verificato qualcosa di inatteso. Riprova più tardi.",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "Richiesta della prova non riuscita perché il server di prova si è comportato in modo errato. Ritenta più tardi.",
    "Trial requested but failed to get account information. Please check back later." : "Versione di prova richiesta, ma impossibile ottenere le informazioni sull'account. Controlla più tardi.",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "Si è verificato un problema con l'autenticazione di questa richiesta. Forse non è raggiungibile dall'esterno per verificare l'URL.",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "Impossibile recuperare le informazioni sull'account perché il server di prova si è comportato in modo errato. Controlla più tardi.",
    "There is a problem with fetching the account information. Please check your logs for further information." : "Si è verificato un problema con il recupero delle informazioni sull'account. Controlla i registri per ulteriori informazioni.",
    "There is no such account registered." : "Non c'è nessun account di questo tipo registrato.",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "Impossibile recuperare le informazioni sull'account perché il server di prova non è raggiungibile. Controlla più tardi.",
    "Deleting the hosted signaling server account failed. Please check back later." : "Eliminazione dell'account del server di segnalazione ospitato non riuscita. Controlla più tardi.",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "Impossibile eliminare l'account perché il server di prova si è comportato in modo errato. Controlla più tardi.",
    "There is a problem with deleting the account. Please check your logs for further information." : "Si è verificato un problema con l'eliminazione dell'account. Controlla i registri per ulteriori informazioni.",
    "Too many requests are sent from your servers address. Please try again later." : "Troppe richieste inviate dall'indirizzo del tuo server. Riprova più tardi.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "Impossibile eliminare l'account perché il server di prova non è raggiungibile. Controlla più tardi.",
    "Note to self" : "Nota a me stesso",
    "A place for your private notes, thoughts and ideas" : "Un posto per i tuoi appunti, pensieri e idee privati",
    "Transcript is AI generated and may contain mistakes" : "La trascrizione è generata dall'IA e potrebbe contenere errori.",
    "Summary is AI generated and may contain mistakes" : "Il riassunto è generato dall'IA e potrebbe contenere errori.",
    "Let's get started!" : "Iniziamo!",
    "**Nextcloud Talk** is a secure, self-hosted communication platform that integrates seamlessly with the Nextcloud ecosystem.\n\n#### Key Features of Nextcloud Talk:\n\n* Chat and messaging in private and group chats\n* Voice and video calls\n* File sharing and integration with other Nextcloud apps\n* Customizable conversation settings, moderation and privacy controls\n* Web, desktop and mobile (iOS and Android)\n* Private & secure communication\n\n Find out more in the [user documentation](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html)." : "**Nextcloud Talk** è una piattaforma di comunicazione sicura e auto-gestita che si integra perfettamente con l'ecosistema Nextcloud.\n\n#### Caratteristiche principali di Nextcloud Talk:\n\n* Chat e messaggistica in chat private e di gruppo\n* Chiamate vocali e videochiamate\n* Condivisione di file e integrazione con altre app Nextcloud\n* Impostazioni di conversazione personalizzabili, moderazione e controlli sulla privacy\n* Web, desktop e mobile (iOS e Android)\n* Comunicazione privata e sicura\n\nPer saperne di più, consulta la [documentazione utente](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html).",
    "# Welcome to Nextcloud Talk\n\nNextcloud Talk is a private and powerful messaging app that integrates with Nextcloud. Chat in private or group conversations, collaborate over voice and video calls, organize webinars and events, customize your conversations and more." : "# Benvenuto su Nextcloud Talk\n\nNextcloud Talk è un'applicazione di messaggistica privata e potente che si integra con Nextcloud. Chat private o di gruppo, collabora tramite chiamate vocali e videochiamate, organizza webinar ed eventi, personalizza le tue conversazioni e molto altro ancora.",
    "## 🎨 Format texts to create rich messages\n\nIn Nextcloud Talk, you can use Markdown syntax to format your messages. For example, apply **bold** or *italic* formatting, or `highlight texts as code`. You can even create tables and add headings to your text.\n\nNeed to fix a typo or change formatting? Edit your message by clicking \"Edit message\" in the message menu." : "## 🎨 Formatta i testi per creare messaggi ricchi\n\nIn Nextcloud Talk, puoi utilizzare la sintassi Markdown per formattare i tuoi messaggi. Ad esempio, puoi applicare la formattazione **grassetto** o *corsivo*, oppure `evidenziare il testo come codice`. Puoi anche creare tabelle e aggiungere intestazioni al tuo testo.\n\nHai bisogno di correggere un errore di battitura o modificare la formattazione? Modifica il tuo messaggio facendo clic su “Modifica messaggio” nel menu del messaggio.",
    "## 🔗 Add attachments and links\n\nAttach files from your Nextcloud Hub using the \"+\" button. Share items from Files and various Nextcloud apps. Some apps even support interactive widgets, for example, the Text app." : "## 🔗 Aggiungi allegati e collegamenti\n\nAllega file dal tuo Nextcloud Hub utilizzando il pulsante “+”. Condividi elementi da File e varie applicazioni Nextcloud. Alcune applicazioni supportano anche widget interattivi, ad esempio l'applicazione Testo.",
    "## 💭 Let the conversations flow: mention users, react to messages and more\n\nYou can mention everybody in the conversation by using %s or mention specific participants by typing \"@\" and picking their name from the list." : "## 🔗 Aggiungi allegati e collegamenti\n\nAllega file dal tuo Nextcloud Hub utilizzando il pulsante %s. Condividi elementi da File e varie applicazioni Nextcloud. Alcune applicazioni supportano anche widget interattivi, ad esempio l'applicazione Testo.",
    "You can reply to messages, forward them to other chats and people, or copy message content." : "È possibile rispondere ai messaggi, inoltrarli ad altre chat e persone oppure copiarne il contenuto.",
    "## ✨ Do more with Smart Picker\n\nSimply type \"/\" or go to the \"+\" menu to open the Smart Picker where you can attach various content to your messages. You can configure the Smart Picker to be able to add items from Nextcloud apps, GIFs, map locations, AI generated content and much more." : "## ✨ Fai di più con Smart Picker\n\nBasta digitare “/” o andare al menu “+” per aprire Smart Picker, dove puoi allegare vari contenuti ai tuoi messaggi. Puoi configurare Smart Picker per poter aggiungere elementi dalle app Nextcloud, GIF, posizioni sulla mappa, contenuti generati dall'intelligenza artificiale e molto altro ancora.",
    "## ⚙️ Manage conversation settings\n\nIn the conversation menu, you can access various settings to manage your conversations, such as:\n* Edit conversation info\n* Manage notifications\n* Apply numerous moderation rules\n* Configure access and security\n* Enable bots\n* and more!" : "## ⚙️ Gestisci le impostazioni delle conversazioni\n\nNel menu delle conversazioni puoi accedere a varie impostazioni per gestire le tue conversazioni, come ad esempio:\n* Modifica le informazioni sulla conversazione\n* Gestisci le notifiche\n* Applica numerose regole di moderazione\n* Configura l'accesso e la sicurezza\n* Abilita i bot\n* e molto altro ancora!",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Emirati Arabi Uniti",
    "Afghanistan" : "Afghanistan",
    "Antigua and Barbuda" : "Antigua e Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Antarctica" : "Antartide",
    "Argentina" : "Argentina",
    "American Samoa" : "Samoa Americane",
    "Austria" : "Austria",
    "Australia" : "Australia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Isole Åland",
    "Azerbaijan" : "Azerbaijan",
    "Bosnia and Herzegovina" : "Bosnia ed Erzegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgio",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Bahrain" : "Bahrein",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint Barthelemy",
    "Bermuda" : "Bermuda",
    "Brunei Darussalam" : "Brunei Darussalam",
    "Bolivia, Plurinational State of" : "Bolivia, Stato Plurinazionale di",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius e Saba",
    "Brazil" : "Brasile",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhutan",
    "Bouvet Island" : "Isola Bouvet",
    "Botswana" : "Botswana",
    "Belarus" : "Bielorussia",
    "Belize" : "Belize",
    "Canada" : "Canada",
    "Cocos (Keeling) Islands" : "Isole Cocos (Keeling)",
    "Congo, the Democratic Republic of the" : "Congo, Repubblica Democratica del",
    "Central African Republic" : "Repubblica Centrafricana",
    "Congo" : "Congo",
    "Switzerland" : "Svizzera",
    "Côte d'Ivoire" : "Costa d'Avorio",
    "Cook Islands" : "Isole di Cook",
    "Chile" : "Cile",
    "Cameroon" : "Camerun",
    "China" : "Cina",
    "Colombia" : "Colombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cabo Verde" : "Capo Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Isola di Natale",
    "Cyprus" : "Cipro",
    "Czechia" : "Cechia",
    "Germany" : "Germania",
    "Djibouti" : "Gibuti",
    "Denmark" : "Danimarca",
    "Dominica" : "Dominica",
    "Dominican Republic" : "Repubblica Dominicana",
    "Algeria" : "Algeria",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estonia",
    "Egypt" : "Egitto",
    "Western Sahara" : "Sahara occidentale",
    "Eritrea" : "Eritrea",
    "Spain" : "Spagna",
    "Ethiopia" : "Etiopia",
    "Finland" : "Finlandia",
    "Fiji" : "Figi",
    "Falkland Islands (Malvinas)" : "Isole Falkland (Malvinas)",
    "Micronesia, Federated States of" : "Micronesia, Stati Federati di",
    "Faroe Islands" : "Isole Faroe",
    "France" : "Francia",
    "Gabon" : "Gabon",
    "United Kingdom of Great Britain and Northern Ireland" : "Regno Unito di Gran Bretagna e Irlanda del Nord",
    "Grenada" : "Grenada",
    "Georgia" : "Georgia",
    "French Guiana" : "Guiana Francese",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibilterra",
    "Greenland" : "Groenlandia",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadalupa",
    "Equatorial Guinea" : "Guinea Equatoriale",
    "Greece" : "Grecia",
    "South Georgia and the South Sandwich Islands" : "Georgia del Sud e Isole Sandwich Australi",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Isole Heard e McDonald",
    "Honduras" : "Honduras",
    "Croatia" : "Croazia",
    "Haiti" : "Haiti",
    "Hungary" : "Ungheria",
    "Indonesia" : "Indonesia",
    "Ireland" : "Irlanda",
    "Israel" : "Israele",
    "Isle of Man" : "Isola di Man",
    "India" : "India",
    "British Indian Ocean Territory" : "Territorio Britannico dell'Oceano Indiani",
    "Iraq" : "Iraq",
    "Iran, Islamic Republic of" : "Iran, Repubblica Islamica dell'",
    "Iceland" : "Islanda",
    "Italy" : "Italia",
    "Jersey" : "Jersey",
    "Jamaica" : "Giamaica",
    "Jordan" : "Giordania",
    "Japan" : "Giappone",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kirghizistan",
    "Cambodia" : "Cambogia",
    "Kiribati" : "Kiribati",
    "Comoros" : "Comore",
    "Saint Kitts and Nevis" : "Saint Kitts e Nevis",
    "Korea, Democratic People's Republic of" : "Corea, Repubblica Democratica Popolare di",
    "Korea, Republic of" : "Corea, Repubblica di",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Isole Cayman",
    "Kazakhstan" : "Kazakistan",
    "Lao People's Democratic Republic" : "Repubblica Democratica Popolare del Laos",
    "Lebanon" : "Libano",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Lituania",
    "Luxembourg" : "Lussemburgo",
    "Latvia" : "Lettonia",
    "Libya" : "Libia",
    "Morocco" : "Marocco",
    "Monaco" : "Monaco",
    "Moldova, Republic of" : "Moldavia, Repubblica di",
    "Montenegro" : "Montenegro",
    "Saint Martin (French part)" : "Saint Martin (parte francese)",
    "Madagascar" : "Madagascar",
    "Marshall Islands" : "Isole Marshall",
    "North Macedonia" : "Macedonia del Nord",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolia",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Isole Marianne settentrionali",
    "Martinique" : "Martinica",
    "Mauritania" : "Mauritania",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauritius",
    "Maldives" : "Maldive",
    "Malawi" : "Malawi",
    "Mexico" : "Messico",
    "Malaysia" : "Malaysia",
    "Mozambique" : "Mozambico",
    "Namibia" : "Namibia",
    "New Caledonia" : "Nuova Caledonia",
    "Niger" : "Niger",
    "Norfolk Island" : "Isola Norfolk",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Paesi Bassi",
    "Norway" : "Norvegia",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Nuova Zelanda",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Perù",
    "French Polynesia" : "Polinesia Francese",
    "Papua New Guinea" : "Papua Nuova Guinea",
    "Philippines" : "Filippine",
    "Pakistan" : "Pakistan",
    "Poland" : "Polonia",
    "Saint Pierre and Miquelon" : "Saint Pierre e Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Porto Rico",
    "Palestine, State of" : "Palestina, Stato di",
    "Portugal" : "Portogallo",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Qatar",
    "Réunion" : "Réunion",
    "Romania" : "Romania",
    "Serbia" : "Serbia",
    "Russian Federation" : "Federazione Russa",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Arabia Saudita",
    "Solomon Islands" : "Isole Salomone",
    "Seychelles" : "Seychelles",
    "Sudan" : "Sudan",
    "Sweden" : "Svezia",
    "Singapore" : "Singapore",
    "Saint Helena, Ascension and Tristan da Cunha" : "Sant'Elena, Ascensione e Tristan da Cunha",
    "Slovenia" : "Slovenia",
    "Svalbard and Jan Mayen" : "Svalbard e Jan Mayen",
    "Slovakia" : "Slovacchia",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Suriname",
    "South Sudan" : "Sudan del Sud",
    "Sao Tome and Principe" : "Sao Tome e Principe",
    "El Salvador" : "El Salvador",
    "Sint Maarten (Dutch part)" : "Sint Maarten (parte olandese)",
    "Syrian Arab Republic" : "Repubblica Araba Siriana",
    "Eswatini" : "Eswatini",
    "Turks and Caicos Islands" : "Isole Turks e Caicos",
    "Chad" : "Ciad",
    "French Southern Territories" : "Terre Australi Francesi",
    "Togo" : "Togo",
    "Thailand" : "Thailandia",
    "Tajikistan" : "Tagikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor Est",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunisia",
    "Tonga" : "Tonga",
    "Turkey" : "Turchia",
    "Trinidad and Tobago" : "Trinidad e Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan, Province of China" : "Taiwan, provincia della Cina",
    "Tanzania, United Republic of" : "Tanzania, Repubblica Unita di",
    "Ukraine" : "Ucraina",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Isole minori esterne degli Stati Uniti d'America",
    "United States of America" : "Stati Uniti d'America",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Uzbekistan",
    "Holy See" : "Città del Vaticano",
    "Saint Vincent and the Grenadines" : "Saint Vincent e Grenadine",
    "Venezuela, Bolivarian Republic of" : "Venezuela, Repubblica Bolivariana di",
    "Virgin Islands, British" : "Isole Vergini, Britanniche",
    "Virgin Islands, U.S." : "Isole Vergini, U.S.A.",
    "Viet Nam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis e Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Yemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Sudafrica",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Background blur" : "Sfondo sfocato",
    "Could not check for WASM loading support. Please check manually if your web server serves `.wasm` files." : "Impossibile verificare il supporto per il caricamento WASM. Verificare manualmente se il server web supporta i file `.wasm`.",
    "Your web server is not properly set up to deliver `.wasm` files. This is typically an issue with the Nginx configuration. For background blur it needs an adjustment to also deliver `.wasm` files. Compare your Nginx configuration to the recommended configuration in our documentation." : "Il tuo server web non è configurato correttamente per fornire file `.wasm`. Si tratta in genere di un problema legato alla configurazione di Nginx. Per la sfocatura dello sfondo è necessario un aggiustamento per fornire anche i file `.wasm`. Confronta la tua configurazione Nginx con quella consigliata nella nostra documentazione.",
    "Talk configuration values" : "Valori di configurazione di Talk",
    "Forcing a call duration is only supported with system cron. Please enable system cron or remove the `max_call_duration` configuration." : "La forzatura della durata delle chiamate è supportata solo con il cron di sistema. Abilita il cron di sistema o rimuovi la configurazione `max_call_duration`.",
    "Small `max_call_duration` values (currently set to %d) are not enforceable due to technical limitations. The background job is only executed every 5 minutes, so use at own risk." : "I valori bassi di `max_call_duration` (attualmente impostato su %d) non sono applicabili a causa di limitazioni tecniche. Il processo in background viene eseguito solo ogni 5 minuti, quindi utilizza questi valori a tuo rischio e pericolo.",
    "Federation" : "Federazione",
    "It is highly recommended to configure \"memcache.locking\" when Talk Federation is enabled." : "Si consiglia vivamente di configurare “memcache.locking” quando Talk Federation è abilitato.",
    "High-performance backend" : "Motore ad alte prestazioni",
    "No High-performance backend configured - Running Nextcloud Talk without the High-performance backend only scales for very small calls (max. 2-3 participants). Please set up the High-performance backend to ensure calls with multiple participants work seamlessly." : "Backend ad alte prestazioni non configurato - L'esecuzione di Nextcloud Talk senza il backend ad alte prestazioni consente di gestire solo chiamate di dimensioni molto ridotte (max. 2-3 partecipanti). Configurare il backend ad alte prestazioni per garantire il corretto funzionamento delle chiamate con più partecipanti.",
    "Running the High-performance backend \"conversation_cluster\" mode is deprecated and will no longer be supported in the upcoming version. The High-performance backend supports real clustering nowadays which should be used instead." : "L'esecuzione della modalità “conversation_cluster” del backend ad alte prestazioni è deprecata e non sarà più supportata nella prossima versione. Il backend ad alte prestazioni supporta attualmente il clustering reale, che dovrebbe essere utilizzato al suo posto.",
    "Defining multiple High-performance backends is deprecated and will no longer be supported in the upcoming version. Instead a load-balancer should be set up together with clustered signaling servers and configured in the Talk settings." : "La definizione di più backend ad alte prestazioni è deprecata e non sarà più supportata nella prossima versione. È invece necessario configurare un bilanciatore di carico insieme a server di segnalazione in cluster e configurarlo nelle impostazioni di Talk.",
    "The stored public key for used algorithm %1$s does not match the stored private key. Run %2$s to fix the issue." : "La chiave pubblica memorizzata per l'algoritmo %1$s non corrisponde alla chiave privata memorizzata. Eseguire %2$s per risolvere il problema.",
    "High-performance backend not configured correctly. Run %s for details." : "Backend ad alte prestazioni non configurato correttamente. Eseguire %s per i dettagli.",
    "High-performance backend not configured correctly" : "Backend ad alte prestazioni non configurato correttamente",
    "Error: Cannot connect to server" : "Errore: impossibile connettersi al server",
    "Error: Server did not respond with proper JSON" : "Errore: il server non ha risposto con il JSON corretto",
    "Error: Certificate expired" : "Errore: Certificato scaduto",
    "Error: System times of Nextcloud server and High-performance backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Errore: gli orari di sistema del server Nextcloud e del server backend ad alte prestazioni non sono sincronizzati. Assicurati che entrambi i server siano collegati a un server di riferimento orario o sincronizza manualmente l'ora.",
    "Could not get version" : "Impossibile ottenere la versione",
    "Error: Running version: {version}; Server needs to be updated to be compatible with this version of Talk" : "Errore: versione in esecuzione: {version}; Il server deve essere aggiornato per essere compatibile con questa versione di Talk",
    "Error: Server responded with: {error}" : "Errore: il server ha risposto con: {error}",
    "Error: Unknown error occurred" : "Errore: si è verificato un errore sconosciuto",
    "Warning: Running version: {version}; Server does not support all features of this Talk version, missing features: {features}" : "Avviso: versione in esecuzione: {version}; Il server non supporta tutte le funzionalità di questa versione di Talk, funzionalità mancanti: {features}",
    "It is highly recommended to configure a memory cache when running Nextcloud Talk with a High-performance backend." : "Si consiglia vivamente di configurare una cache di memoria quando si esegue Nextcloud Talk con un backend ad alte prestazioni.",
    "Client Push" : "Client Push",
    "Recording backend" : "Backend di registrazione",
    "Using the recording backend requires a High-performance backend." : "L'utilizzo del backend di registrazione richiede un backend ad alte prestazioni.",
    "No recording backend configured" : "Nessun backend di registrazione configurato",
    "SIP configuration" : "Configurazione SIP",
    "Using the SIP functionality requires a High-performance backend." : "L'utilizzo della funzionalità SIP richiede un backend ad alte prestazioni.",
    "No SIP backend configured" : "Nessun backend SIP configurato",
    "Invalid date, date format must be YYYY-MM-DD" : "Data non valida, il formato della data deve essere AAAA-MM-GG",
    "Conversation not found" : "Conversazione non trovata",
    "Path is already shared with this conversation" : "Il percorso è già condiviso con questa conversazione",
    "Chat, video & audio-conferencing using WebRTC" : "Chat, video e audio conferenze utilizzando WebRTC",
    "Chat, video & audio-conferencing using WebRTC\n\n* 💬 **Chat** Nextcloud Talk comes with a simple text chat, allowing you to share or upload files from your Nextcloud Files app or local device and mention other participants.\n* 👥 **Private, group, public and password protected calls!** Invite someone, a whole group or send a public link to invite to a call.\n* 🌐 **Federated chats** Chat with other Nextcloud users on their servers\n* 💻 **Screen sharing!** Share your screen with the participants of your call.\n* 🚀 **Integration with other Nextcloud apps** like Files, Calendar, User status, Dashboard, Flow, Maps, Smart picker, Contacts, Deck, and many more.\n* 🌉 **Sync with other chat solutions** With [Matterbridge](https://github.com/42wim/matterbridge/) being integrated in Talk, you can easily sync a lot of other chat solutions to Nextcloud Talk and vice-versa." : "Chat, videoconferenze e audioconferenze tramite WebRTC\n\n* 💬 **Chat** Nextcloud Talk include una semplice chat di testo che consente di condividere o caricare file dall'applicazione Nextcloud Files o dal dispositivo locale e menzionare altri partecipanti.\n* 👥 **Chiamate private, di gruppo, pubbliche e protette da password!** Invita una persona, un intero gruppo o invia un collegamento pubblico per invitare qualcuno a una chiamata.\n* 🌐 **Chat federate** Partecipa a chat con altri utenti Nextcloud sui loro server\n* 💻 **Condivisione dello schermo!** Condividi il tuo schermo con i partecipanti alla tua chiamata.\n* 🚀 **Integrazione con altre applicazioni Nextcloud** come Files, Calendar, User status, Dashboard, Flow, Maps, Smart picker, Contacts, Deck e molte altre.\n* 🌉 **Sincronizzazione con altre soluzioni di chat** Con [Matterbridge](https://github.com/42wim/matterbridge/) integrato in Talk, puoi sincronizzare facilmente molte altre soluzioni di chat con Nextcloud Talk e viceversa.",
    "Leave call" : "Lascia la chiamata",
    "Navigating away from the page will leave the call in {conversation}" : "L'abbandono della pagina causerà l'uscita dalla chiamata in {conversation}",
    "Stay in call" : "Rimani in conversazione",
    "Error occurred when getting the conversation information" : "Si è verificato un errore durante il recupero delle informazioni sulla conversazione",
    "Discuss this file" : "Discuti questo file",
    "Share this file with others to discuss it" : "Condividi questo file con altri per discuterne",
    "Share this file" : "Condividi questo file",
    "Join conversation" : "Unisciti alla conversazione",
    "This conversation is password-protected." : "Questa conversazione è protetta da password.",
    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "Abbiamo rilevato diversi tentativi di accesso con password non valida dal tuo indirizzo IP. Pertanto, il tuo prossimo tentativo sarà ritardato di 30 secondi.",
    "The password is wrong. Try again." : "La password è errata. Prova ancora.",
    "Password" : "Password",
    "Submit" : "Invia",
    "Error requesting the password." : "Errore durante la richiesta della password",
    "Request password" : "Richiedi password",
    "This conversation has ended" : "Questa conversazione è terminata",
    "Error occurred when joining the conversation" : "Si è verificato un errore durante l'adesione alla conversazione",
    "Close Talk sidebar" : "Chiudi la barra laterale di Talk",
    "Open Talk sidebar" : "Aprire la barra laterale di Talk",
    "Everyone" : "Tutti",
    "Users and moderators" : "Utenti e moderatori",
    "Moderators only" : "Solo i moderatori",
    "Disable calls" : "Disabilita chiamate",
    "Save changes" : "Salva le modifiche",
    "Saving …" : "Salvataggio in corso...",
    "Saved!" : "Salvato!",
    "Limit to groups" : "Limita a gruppi",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Quando almeno un gruppo è selezionato, solo le persone dei gruppi elencati possono prendere parte alla conversazione.",
    "Guests can still join public conversations." : "Gli ospiti possono unirsi a conversazioni pubbliche.",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Gli utenti che non possono più usare Talk verranno comunque elencati tra i partecipanti nelle loro conversazioni precedenti e verranno anche mantenuti i loro messaggi.",
    "Limit using Talk" : "Limita l'utilizzo di Talk",
    "Limit creating a public and group conversation" : "Limita alla creazione di una conversazione pubblica e di gruppo",
    "Limit creating conversations" : "Limita la creazione di conversazioni",
    "Limit starting a call" : "Limita l'inizio di una chiamata",
    "Limit starting calls" : "Limita l'inizio della chiamate",
    "When a call has started, everyone with access to the conversation can join the call." : "Quando una chiamata è iniziata, chiunque abbia accesso alla conversazione può unirsi alla chiamata.",
    "The following bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "I seguenti bot sono installati su questo server. Nella documentazione puoi trovare i dettagli su come {linkstart1}creare il tuo bot{linkend} o una {linkstart2}lista di bot{linkend} da abilitare sul tuo server.",
    "No bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Nessun bot è installato su questo server. Nella documentazione puoi trovare i dettagli su come {linkstart1}creare il tuo bot{linkend} o una {linkstart2}lista di bot{linkend} da abilitare sul tuo server.",
    "Description is not provided" : "Descrizione non fornita",
    "Locked for moderators" : "Bloccato dai moderatori",
    "Enabled" : "Abilitata",
    "Disabled" : "Disattivato",
    "Bots settings" : "Impostazioni dei bot",
    "State" : "Stato",
    "Name" : "Nome",
    "Last error" : "Ultimo errore",
    "Total errors count" : "Numero totale errori",
    "Find more bots" : "Trova altri bot",
    "Trusted servers can be configured at {linkstart}Sharing settings page{linkend}." : "I server attendibili possono essere configurati nella pagina {linkstart}Impostazioni di condivisione{linkend}.",
    "Beta" : "Beta",
    "Federated chats and calls work already. Attachment handling is coming in a future version." : "Le chat e le chiamate federate funzionano già. La gestione degli allegati sarà disponibile in una versione futura.",
    "Enable Federation in Talk app" : "Abilita la federazione nell'applicazione Talk",
    "Permissions" : "Permessi",
    "Allow users to be invited to federated conversations" : "Consenti agli utenti di essere invitati a conversazioni federate",
    "Allow users to invite federated users into conversation" : "Consenti agli utenti di invitare utenti federati nella conversazione",
    "Only allow to federate with trusted servers" : "Consenti solo la federazione con server affidabili",
    "When at least one group is selected, only people of the listed groups can invite federated users to conversations." : "Quando è selezionato almeno un gruppo, solo le persone appartenenti ai gruppi elencati possono invitare utenti federati alle conversazioni.",
    "Groups allowed to invite federated users" : "Gruppi autorizzati a invitare utenti federati",
    "Select groups …" : "Seleziona gruppi …",
    "All messages" : "Tutti i messaggi",
    "@-mentions only" : "solo @-menzioni",
    "Off" : "Spento",
    "General settings" : "Impostazioni generali",
    "Default notification settings" : "Impostazioni di notifica predefinite",
    "Default group notification" : "Notifica di gruppo predefinita",
    "Default group notification for new groups" : "Notifica di gruppo predefinita per i nuovi gruppi",
    "Integration into other apps" : "Integrazione in altre applicazioni",
    "Allow conversations on files" : "Consenti conversazioni su file",
    "Allow conversations on public shares for files" : "Consenti conversazioni su condivisioni pubbliche per i file",
    "End-to-end encrypted calls" : "Chiamate crittografate end-to-end",
    "Enable encryption" : "Abilita cifratura",
    "End-to-end encrypted calls with a configured SIP bridge require a newer version of the High-performance backend and SIP bridge." : "Le chiamate crittografate end-to-end con un bridge SIP configurato richiedono una versione più recente del backend ad alte prestazioni e del bridge SIP.",
    "Mobile clients do not support end-to-end encrypted calls at the moment." : "Al momento i client mobili non supportano le chiamate crittografate end-to-end.",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "Facendo clic sul pulsante sopra le informazioni nel modulo sono inviate ai server di Struktur AG. Ulteriori informazioni sono disponibili su {linkstart}spreed.eu{linkend}.",
    "Pending" : "In corso",
    "Error" : "Errore",
    "Blocked" : "Bloccati",
    "Active" : "Attivo",
    "Expired" : "Scaduto",
    "Never" : "Mai",
    "The trial could not be requested. Please try again later." : "La prova non può essere richiesta. Riprova più tardi.",
    "The account could not be deleted. Please try again later." : "Non è stato possibile eliminare l'account. Riprova più tardi.",
    "Hosted High-performance backend" : "Backend hosted ad alte prestazioni",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "Il nostro partner Struktur AG fornisce un servizio in cui è possibile richiedere un server di segnalazione ospitato. Per questo è sufficiente compilare il modulo sottostante e Nextcloud lo richiederà. Una volta impostato il server, le credenziali saranno riempite automaticamente. Ciò sovrascriverà le impostazioni esistenti del server di segnalazione.",
    "If your high-performance backend account includes STUN and/or TURN functionality, the settings will be updated accordingly." : "Se il tuo account backend ad alte prestazioni include le funzionalità STUN e/o TURN, le impostazioni verranno aggiornate di conseguenza.",
    "URL of this Nextcloud instance" : "URL di questa istanza Nextcloud",
    "Full name of the user requesting the trial" : "Nome completo dell'utente che richiede la prova",
    "Email of the user" : "Indirizzo di posta dell'utente",
    "Language" : "Lingua",
    "Country" : "Nazione",
    "Request signaling server trial" : "Richiesta della prova del server di segnalazione",
    "You can see the current status of your hosted signaling server in the following table." : "Puoi visualizzare lo stato attuale del server di segnalazione ospitato nella seguente tabella.",
    "Status" : "Stato",
    "Created at" : "Creato il",
    "Expires at" : "Scade il",
    "Limits" : "Limiti",
    "STUN included" : "STUN incluso",
    "Yes" : "Sì",
    "No" : "No",
    "TURN included" : "TURN incluso",
    "Delete the signaling server account" : "Elimina l'account del server di segnalazione",
    "_%n user_::_%n users_" : ["%n utente","%n utenti","%n utenti"],
    "Installed version: {version}" : "Versione installata: {version}",
    "You can install the Matterbridge to link Nextcloud Talk to some other services, visit their {linkstart1}GitHub page{linkend} for more details. Downloading and installing the app can take a while. In case it times out, please install it manually from the {linkstart2}Nextcloud App Store{linkend}." : "È possibile installare Matterbridge per collegare Nextcloud Talk ad altri servizi. Per ulteriori dettagli, visitare la {linkstart1}pagina GitHub{linkend}. Il download e l'installazione dell'app potrebbero richiedere un po' di tempo. In caso di timeout, installarla manualmente dall'{linkstart2}App Store di Nextcloud{linkend}.",
    "Matterbridge binary has incorrect permissions. Please make sure the Matterbridge binary file is owned by the correct user and can be executed. It can be found in \"/…/nextcloud/apps/talk_matterbridge/bin/\"." : "Il file binario Matterbridge ha autorizzazioni errate. Assicurati che il file binario Matterbridge sia di proprietà dell'utente corretto e che possa essere eseguito. Si trova in “/…/nextcloud/apps/talk_matterbridge/bin/”.",
    "Matterbridge binary was not found or couldn't be executed." : "Il binario di Matterbridge non è stato trovato o non può essere eseguito.",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "Puoi impostare il percorso del binario di Matterbridge anche manualmente tramite la configurazione. Controlla la {linkstart}documentazione di integrazione di Matterbridge{linkend} per ulteriori informazioni.",
    "Downloading …" : "Scaricamento…",
    "Install Talk Matterbridge" : "Installa Talk Matterbridge",
    "An error occurred while installing the Matterbridge app" : "Si è verificato un errore durante l'installazione dell'applicazione Matterbridge",
    "An error occurred while installing the Talk Matterbridge. Please install it manually" : "Si è verificato un errore durante l'installazione di Talk Matterbridge. Installalo manualmente.",
    "Failed to execute Matterbridge binary." : "Esecuzione del binario di Matterbridge non riuscita.",
    "Matterbridge integration" : "Integrazione con Matterbridge",
    "Enable Matterbridge integration" : "Attiva l'integrazione con Matterbridge",
    "Status: Checking connection" : "Stato: controllo della connessione",
    "OK: Running version: {version}" : "OK: versione in esecuzione: {version}",
    "Error: Server seems to be a Signaling server" : "Errore: il server sembra essere un server di segnalazione",
    "Error: System times of Nextcloud server and Recording backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Errore: gli orari di sistema del server Nextcloud e del server di backend di registrazione non sono sincronizzati. Assicurati che entrambi i server siano collegati a un server di sincronizzazione oraria o sincronizza manualmente l'ora.",
    "Recording backend URL" : "URL del backend di registrazione",
    "Validate SSL certificate" : "Convalida certificato SSL",
    "Delete this server" : "Elimina questo server",
    "Test this server" : "Prova questo server",
    "Disabled for all calls" : "Disabilitato per tutte le chiamate",
    "Enabled for all calls" : "Abilitato per tutte le chiamate",
    "Configurable on conversation level by moderators" : "Configurabile a livello di conversazione dai moderatori",
    "The PHP settings \"upload_max_filesize\" or \"post_max_size\" only will allow to upload files up to {maxUpload}." : "Le impostazioni PHP “upload_max_filesize” o “post_max_size” consentono solo di caricare file fino a {maxUpload}.",
    "Recording backend settings saved" : "Impostazioni di registrazione backend salvate",
    "Moderators will be allowed to enable consent on conversation level. The consent to be recorded will be required for each participant before joining every call in this conversation." : "I moderatori potranno abilitare il consenso a livello di conversazione. Il consenso alla registrazione sarà richiesto a ciascun partecipante prima di partecipare a ogni chiamata nell'ambito di tale conversazione.",
    "The consent to be recorded will be required for each participant before joining every call." : "Il consenso per la registrazione sarà richiesto ad ogni partecipante prima di accedere a ciascuna chiamata.",
    "The consent to be recorded is not required." : "Il consenso per la registrazione non è necessario.",
    "Recording backend configuration is only possible with a High-performance backend." : "La configurazione del backend di registrazione è possibile solo con un backend ad alte prestazioni.",
    "Add a new recording backend server" : "Aggiungi un nuovo server di backend per la registrazione",
    "Shared secret" : "Segreto condiviso",
    "Recording consent" : "Permesso di registrazione",
    "Recording transcription" : "Registrazione della trascrizione",
    "Automatically transcribe call recordings with a transcription provider" : "Trascrivi automaticamente le registrazioni delle chiamate con un fornitore di servizi di trascrizione",
    "Automatically summarize call recordings with transcription and summary providers" : "Riassumi automaticamente le registrazioni delle chiamate con fornitori di trascrizioni e riassunti",
    "SIP configuration saved!" : "Configurazione SIP salvata!",
    "SIP configuration is only possible with a High-performance backend." : "La configurazione SIP è possibile solamente con un backend ad alte prestazione.",
    "Enable SIP Dial-out option" : "Abilita l'opzione chiamata in uscita SIP ",
    "Signaling server needs to be updated to supported SIP Dial-out feature." : "Il server di segnalazione deve essere aggiornato per supportare la funzione di chiamata in uscita SIP.",
    "Do not show SIP Dial-out caller number" : "Non mostrare il numero del chiamate delle chiamate in uscita SIP",
    "Anonymous number should appear as \"unknown\" or \"withheld number\" to call recipient" : "Il numero anonimo dovrebbe apparire come “sconosciuto” o “numero nascosto” al destinatario della chiamata.",
    "Dial-out number" : "Numero di uscita",
    "E164 formatted number used as a fallback caller number for outgoing calls" : "Numero in formato E164 utilizzato come numero di chiamata di riserva per le chiamate in uscita",
    "Dial-out prefix" : "Prefisso in uscita",
    "Prefix to configured user number for outgoing calls (default is `+`)" : "Prefisso al numero utente configurato per le chiamate in uscita (il valore predefinito è `+`)",
    "Restrict SIP configuration" : "Limita configurazione SIP",
    "Enable SIP configuration" : "Abilita configurazione SIP",
    "Only users of the following groups can enable SIP in conversations they moderate" : "Solo gli utenti dei seguenti gruppi possono abilitare SIP nelle conversazioni che moderano",
    "Phone number (Country)" : "Numero di telefono (Nazione)",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "Queste informazioni sono inviate tramite email di invito e visualizzate nella barra laterale a tutti i partecipanti.",
    "Nextcloud base URL" : "URL base di Nextcloud",
    "Talk Backend URL" : "URL del backend di Talk",
    "WebSocket URL" : "URL del WebSocket",
    "Available features" : "Funzionalità disponibili",
    "Error: Websocket connection failed" : "Errore: connessione Websocket non riuscita",
    "Error code" : "Codice errore",
    "Error message" : "Messaggio d'errore",
    "Error: Websocket connection failed. Check browser console" : "Errore: connessione Websocket non riuscita. Controllare la console del browser.",
    "High-performance backend URL" : "URL del motore ad alte prestazioni",
    "Missing High-performance backend warning hidden" : "Avviso nascosto relativo al backend ad alte prestazioni mancante",
    "High-performance backend settings saved" : "Impostazioni backend ad alte prestazioni salvate",
    "Nextcloud Talk setup not complete" : "Configurazione di Nextcloud Talk non completata",
    "Please note that in calls with more than 2 participants without the High-performance backend, participants will most likely experience connectivity issues and cause high load on participating devices." : "Si prega di notare che nelle chiamate con più di 2 partecipanti senza il backend ad alte prestazioni, i partecipanti potrebbero riscontrare problemi di connettività e causare un carico elevato sui dispositivi partecipanti.",
    "Install the High-performance backend to ensure calls with multiple participants work seamlessly." : "Installa il backend ad alte prestazioni per garantire che le chiamate con più partecipanti funzionino senza problemi.",
    "Nextcloud portal" : "Portale di Nextcloud",
    "Quick installation guide" : "Guida all'Installazione Rapida",
    "The High-performance backend is required for calls and conversations with multiple participants. Without the backend, all participants have to upload their own video individually for each other participant, which will most likely cause connectivity issues and a high load on participating devices." : "Il backend ad alte prestazioni è necessario per le chiamate e le conversazioni con più partecipanti. Senza il backend, tutti i partecipanti devono caricare individualmente il proprio video per ciascuno degli altri partecipanti, il che molto probabilmente causerà problemi di connettività e un carico elevato sui dispositivi partecipanti.",
    "It is highly recommended to set up a distributed cache when using Nextcloud Talk with a High-performance backend." : "Si consiglia vivamente di configurare una cache distribuita quando si utilizza Nextcloud Talk con un backend ad alte prestazioni.",
    "Add High-performance backend server" : "Aggiungi server backend ad alte prestazioni",
    "Warn about connectivity issues in calls with more than 2 participants" : "Avvisa in caso di problemi di connettività nelle chiamate con più di 2 partecipanti",
    "STUN server URL" : "URL server STUN",
    "The server address is invalid" : "L'indirizzo del server non è valido",
    "STUN settings saved" : "Impostazioni STUN salvate",
    "STUN servers" : "Server STUN",
    "A STUN server is used to determine the public IP address of participants behind a router." : "Un server STUN è utilizzato per determinare l'indirizzo IP pubblico dei partecipanti dietro a un router.",
    "Add a new STUN server" : "Aggiungi un nuovo server STUN",
    "{schema} scheme must be used with a domain" : "Lo schema {schema} deve essere utilizzata con un dominio",
    "{option1} and {option2}" : "{option1} e {option2}",
    "{option} only" : "solo {option}",
    "OK: Successful ICE candidates returned by the TURN server" : "OK: Candidati ICE validi restituiti dal server TURN",
    "Error: No working ICE candidates returned by the TURN server" : "OK: Candidati ICE non funzionanti restituiti dal server TURN",
    "Testing whether the TURN server returns ICE candidates" : "Verifica se il server TURN restituisce candidati",
    "TURN server schemes" : "Schemi del server TURN",
    "TURN server URL" : "URL server TURN",
    "TURN server secret" : "Segreto del server TURN",
    "TURN server protocols" : "Protocolli server TURN",
    "A TURN server is used to proxy the traffic from participants behind a firewall. If individual participants cannot connect to others a TURN server is most likely required. See {linkstart}this documentation{linkend} for setup instructions." : "Un server TURN viene utilizzato per inoltrare il traffico dai partecipanti dietro un firewall. Se i singoli partecipanti non possono connettersi ad altri, è molto probabile che sia richiesto un server TURN. Vedi {linkstart}questa documentazione{linkend} per le istruzioni di configurazione.",
    "TURN settings saved" : "Impostazioni TURN salvate",
    "TURN servers" : "Server TURN",
    "Add a new TURN server" : "Aggiungi un nuovo server TURN",
    "Failed" : "Non riuscito",
    "OK" : "OK",
    "Checking …" : "Controllo in corso…",
    "Failed: WebAssembly is disabled or not supported in this browser. Please enable WebAssembly or use a browser with support for it to do the check." : "Fallito: WebAssembly è disabilitato o non è supportato in questo browser. Abilita WebAssembly o utilizza un browser con supporto per eseguire il controllo.",
    "Failed: \".wasm\" and \".tflite\" files were not properly returned by the web server. Please check \"System requirements\" section in Talk documentation." : "Fallito: i file \".wasm\" e \".tflite\" non sono stati restituiti correttamente dal server Web. Si prega di controllare la sezione \"Requisiti di sistema\" nella documentazione di Talk.",
    "OK: \".wasm\" and \".tflite\" files were properly returned by the web server." : "OK: i file \".wasm\" e \".tflite\" sono stati correttamente restituiti dal server web.",
    "It seems that the PHP and Apache configuration is not compatible. Please note that PHP can only be used with the MPM_PREFORK module and PHP-FPM can only be used with the MPM_EVENT module." : "Sembra che la configurazione PHP e Apache non sia compatibile. Si prega di notare che PHP può essere utilizzato solo con il modulo MPM_PREFORK e PHP-FPM può essere utilizzato solo con il modulo MPM_EVENT.",
    "Web server setup checks" : "Verifiche della configurazione del server Web",
    "Files required for virtual background can be loaded" : "È possibile caricare i file necessari per lo sfondo virtuale",
    "Federated user" : "Utente federato",
    "Assign participants to rooms" : "Assegna i partecipanti alle stanze",
    "Configure breakout rooms" : "Configura le sessioni secondarie",
    "Number of breakout rooms" : "Numero di sessioni secondarie",
    "You can create from 1 to 20 breakout rooms." : "Puoi creare da 1 a 20 sessioni secondarie.",
    "Assignment method" : "Metodo d'assegnazione",
    "Automatically assign participants" : "Assegna automaticamente partecipanti",
    "Manually assign participants" : "Assegna manualmente partecipanti",
    "Allow participants to choose" : "Permetti ai partecipanti di scegliere",
    "Create rooms" : "Crea stanze",
    "Confirm" : "Conferma",
    "Create breakout rooms" : "Crea sessioni secondarie",
    "Reset" : "Ripristina",
    "Delete breakout rooms" : "Elimina sessioni secondarie",
    "Room {roomNumber}" : "Stanza {roomNumber}",
    "Current breakout rooms and settings will be lost" : "Le attuali sessioni secondarie ed impostazioni saranno perse",
    "Cancel" : "Annulla",
    "Unassigned participants" : "Partecipanti non assegnati",
    "Back" : "Indietro",
    "Assign" : "Assegna",
    "Add participant \"{user}\"" : "Aggiungi il partecipante \"{user}\"",
    "Now" : "Ora",
    "Invalid calendar selected" : "Selezione del calendario non valida",
    "Invalid start time selected" : "Selezione del tempo di inizio non valida",
    "Invalid end time selected" : "Selezione del tempo di fine non valida",
    "Unknown error occurred" : "È avvenuto un errore sconosciuto",
    "Sending no invitations" : "Nessun invio di inviti",
    "{participant0} will receive an invitation" : "{participant0} riceverà un invito",
    "{participant0} and {participant1} will receive invitations" : "{participant0} e {participant1} riceveranno un invito",
    "_{participant0}, {participant1} and %n other will receive invitations_::_{participant0}, {participant1} and %n others will receive invitations_" : ["{participant0}, {participant1} e %n altro riceveranno un invito ","{participant0}, {participant1} e %n altri riceveranno un invito ","{participant0}, {participant1} e %n altri riceveranno un invito "],
    "Invite {user}" : "Invita {user}",
    "Invite all users and emails in this conversation" : "Invita tutti gli utenti e email in questa conversazione",
    "Meeting created" : "Meeting creato",
    "Upcoming meetings" : "Prossimi meetings",
    "Loading …" : "Caricamento…",
    "No upcoming meetings" : "Nessun prossimo meeting ",
    "Schedule a meeting" : "Programma un meeting",
    "Meeting title" : "Titolo del Meeting",
    "From" : "Da",
    "To" : "A",
    "Calendar" : "Calendario",
    "Attendees" : "Partecipanti",
    "No other participants to send invitations to." : "Nessun altro partecipante a cui mandare un invito.",
    "Add attendees" : "Aggiungi partecipanti",
    "Save" : "Salva",
    "Search participants" : "Cerca partecipanti",
    "No results" : "Nessun risultato",
    "Done" : "Completato",
    "Disable live transcription" : "Disattiva trascrizione in tempo reale",
    "Translated language" : "Lingua tradotta",
    "Translated language: {languageName}" : "Lingua tradotta: {languageName}",
    "Raise hand" : "Alza la mano",
    "Raise hand (R)" : "Alza la mano (R)",
    "Lower hand" : "Abbassa la mano",
    "Lower hand (R)" : "Abbassa la mano (R)",
    "Exit full screen (F)" : "Esci dalla modalità a schermo intero (F)",
    "Full screen (F)" : "Schermo intero (F)",
    "Speaker view" : "Visualizzazione oratore",
    "Grid view" : "Vista Griglia",
    "Error when trying to load the available live transcription languages" : "Errore durante il caricamento dei linguaggi disponibili per la trascrizione in  tempo reale",
    "Failed to enable live transcription" : "Impossibile abilitare la trascrizione in tempo reale",
    "Recording consent is required" : "È necessario il consenso alla registrazione",
    "This conversation is read-only" : "Questa conversazione è in sola lettura",
    "Conversation not found or not joined" : "Conversazione non trovata o non avviata",
    "Lobby is still active and you're not a moderator" : "La lobby è ancora attiva e tu non sei un moderatore",
    "Connection failed" : "Connessione fallita",
    "Reload" : "Ricarica",
    "{nickName} raised their hand." : "{nickName} ha alzato la mano.",
    "A participant raised their hand." : "Un partecipante ha alzato la mano.",
    "Collapse stripe" : "Contrai striscia",
    "Expand stripe" : "Espandi striscia",
    "Previous page of videos" : "Pagina di video precedente",
    "Next page of videos" : "Pagina di video successiva",
    "Connecting …" : "Connessione in corso…",
    "Calling …" : "Sto chiamando …",
    "Waiting for {user} to join the call" : "In attesa che {user} si unisca alla chiamata",
    "Waiting for others to join the call …" : "In attesa che altri si uniscano alla chiamata...",
    "You can invite others in the participant tab of the sidebar" : "Puoi invitare altri nella scheda dei partecipanti della barra laterale",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Puoi invitare altri nella scheda dei partecipanti della barra laterale o condividere questo collegamento per invitarli!",
    "Share this link to invite others!" : "Condividi questo collegamento per invitare altri!",
    "Copy link" : "Copia collegamento",
    "You are not allowed to enable audio" : "Non sei autorizzato ad abilitare l'audio",
    "No audio. Click to select device" : "Nessun audio. Premi per selezionare il dispositivo",
    "Mute audio" : "Silenzia audio",
    "Mute audio (M)" : "Silenzia audio (M)",
    "Unmute audio" : "Rimuovi silenzio audio",
    "Unmute audio (M)" : "Rimuovi silenzio audio (M)",
    "None" : "Nessuno",
    "Select a microphone" : "Seleziona un microfono",
    "Select a speaker" : "Seleziona un'uscita",
    "Check devices" : "Controlla dispositivi",
    "Access to camera was denied" : "L'accesso alla fotocamera è stato negato",
    "Error while accessing camera: It is likely in use by another program" : "Errore durante l'accesso alla fotocamera: È probabile che sia utilizzata da un altro programma",
    "Error while accessing camera" : "Errore durante l'accesso alla fotocamera",
    "You have been muted by a moderator" : "Sei stato silenziato da un moderatore",
    "Hide presenter video" : "Nascondi video del presentatore",
    "You are not allowed to enable video" : "Non sei autorizzato ad abilitare il video",
    "No video. Click to select device" : "Nessun video. Premi per selezionare il dispositivo",
    "Disable video" : "Disabilita video",
    "Disable video (V)" : "Disabilita video (V)",
    "Enable video" : "Abilita video",
    "Enable video (V)" : "Abilita video (V)",
    "Enable video - Your connection will be briefly interrupted when enabling the video for the first time" : "Attiva video - La tua connessione sarà brevemente interrotta mentre si attiva il video per la prima volta",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "Abilita video (V) - La tua connessione sarà interrotta brevemente quando abiliti il video per la prima volta",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Abilita video. La tua connessione sarà interrotta brevemente quando abiliti il video per la prima volta",
    "Select a video device" : "Seleziona un dispositivo video",
    "Show presenter" : "Mostra presentatore",
    "You" : "Tu",
    "Mute" : "Silenzia",
    "Muted" : "Mutato",
    "Show screen" : "Mostra schermo",
    "Stop following" : "Smetti di seguire",
    "Connection could not be established …" : "Impossibile stabilire la connessione...",
    "Connection was lost and could not be re-established …" : "La connessione è stata persa e non è stato possibile ristabilirla...",
    "Connection could not be established. Trying again …" : "Impossibile stabilire la connessione. Riprova...",
    "Connection lost. Trying to reconnect …" : "Connessione persa. Tentativo di riconnessione...",
    "Connection problems …" : "Problemi di connessione...",
    "Collapse" : "Contrai",
    "Expand" : "Espandi",
    "You need to be logged in to upload files" : "Devi aver eseguito l'accesso per caricare file",
    "Drop your files to upload" : "Rilascia i tuoi file per caricarli",
    "Conversation messages" : "Messaggi della conversazione",
    "Scroll to bottom" : "Scorri in fondo",
    "Post message" : "Pubblica messaggio",
    "Federated conversation" : "Conversazione federata",
    "Public conversation" : "Conversazione pubblica",
    "Favorite" : "Preferito",
    "Banned users" : "Utenti banditi",
    "Manage the list of banned users in this conversation." : "Gestisci la lista degli utenti banditi in questa conversazione",
    "Manage bans" : "Gestisci ban",
    "No banned users" : "Nessun utente bandito",
    "Banned by:" : "Bandito da:",
    "Date:" : "Data:",
    "Note:" : "Nota:",
    "Hide details" : "Nascondi dettagli",
    "Show details" : "Mostra dettagli",
    "Unban" : "Rimuovi bando",
    "You can change the title and the description in {linkstart}Calendar ↗{linkend}." : "Puoi cambiare il titolo e la descrizione nel {linkstart}Calendario ↗{linkend}.",
    "Error while updating conversation name" : "Errore durante l'aggiornamento del nome della conversazione",
    "Error while updating conversation description" : "Errore durante l'aggiornamento della descrizione della conversazione",
    "Enter a name for this conversation" : "Inserisci un nome per la conversazione",
    "Edit conversation name" : "Modifica nome conversazione",
    "Edit conversation description" : "Modifica la descrizione della conversazione",
    "Enter a description for this conversation" : "Inserisci una descrizione per questa conversazione",
    "Picture" : "Immagine",
    "The following bots can be enabled in this conversation. Reach out to your administration to get more bots installed on this server." : "I seguenti bot possono essere abilitati in questa conversazione. Contatta il tuo amministratore per installare altri bot su questo server.",
    "No bots are installed on this server. Reach out to your administration to get bots installed on this server." : "Nessun bot è installato su questo server. Contatta il tuo amministratore per installare bot su questo server.",
    "Disable" : "Disabilita",
    "Enable" : "Abilita",
    "Breakout rooms" : "Sessioni secondarie",
    "Manage breakout rooms" : "Gestisci sessioni secondarie",
    "Set up breakout rooms for this conversation" : "Imposta sessioni secondarie per questa conversazione",
    "Please select a valid PNG or JPG file" : "Seleziona un file PNG o JPG valido",
    "Choose your conversation picture" : "Scegli l'icona della conversazione",
    "Choose" : "Scegli",
    "Error setting conversation picture" : "Errore nell'impostazione dell'icona della conversazione",
    "Could not set the conversation picture: {error}" : "Impossibile impostare icona conversazione: {error}",
    "Error cropping conversation picture" : "Abilita ritaglio dell'icona della conversazione",
    "Error removing conversation picture" : "Errore nella rimozione dell'icona della conversazione",
    "Set emoji as conversation picture" : "Imposta emoji come icona della conversazione",
    "Set background color for conversation picture" : "Imposta colore di sfondo per l'icona della conversazione",
    "Upload conversation picture" : "Carica immagine della conversazione",
    "Choose conversation picture from files" : "Scegli icona della conversazione dai file",
    "Remove conversation picture" : "Rimuove icona della conversazione",
    "The file must be a PNG or JPG" : "Il file deve essere una PNG o JPG",
    "Set picture" : "Imposta icona",
    "Default permissions modified for {conversationName}" : "Permessi predefiniti modificati per {conversationName}",
    "Could not modify default permissions for {conversationName}" : "Impossibile modificare i permessi predefiniti per {conversationName}",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "Modifica i permessi predefiniti per i partecipanti di questa conversazione. Queste impostazioni non hanno effetto sui moderatori.",
    "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "Ogni volta che i permessi vengono modificati in questa sezione i permessi impostati precedentemente a singoli partecipanti vanno perduti.",
    "All permissions" : "Tutti permessi",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "I partecipanti hanno le autorizzazioni per avviare una chiamata, partecipare a una chiamata, abilitare audio e video e condividere lo schermo.",
    "Restricted" : "Limitato",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "I partecipanti possono partecipare alle chiamate, ma non possono abilitare né audio né video né condividere lo schermo finché un moderatore non concede loro manualmente i permessi.",
    "Advanced permissions" : "Permessi avanzati",
    "Edit permissions" : "Modifica permessi",
    "Conversation settings" : "Impostazioni conversazione",
    "Basic Info" : "Informazioni di base",
    "Personal" : "Personale",
    "Moderation" : "Moderazione",
    "Setup overview" : "Panoramica della configurazione",
    "Live transcription" : "Trascrizione in tempo reale",
    "Enable live transcription" : "Avvia trascrizione in tempo reale",
    "Breakout Rooms" : "Sessioni Secondarie",
    "Matterbridge" : "Matterbridge",
    "Bots" : "Bot",
    "Danger zone" : "Zona pericolosa",
    "Archive conversation" : "Archivia conversazione",
    "Archived conversations are hidden from the conversation list by default. However, they will still appear when you search for the conversation name or access a list of archived conversations." : "Le conversazioni archiviate sono nascoste dall'elenco delle conversazioni per impostazione predefinita. Tuttavia, saranno comunque visibili quando si cerca il nome della conversazione o si accede a un elenco di conversazioni archiviate.",
    "Do you really want to leave \"{displayName}\"?" : "Vuoi davvero uscire da “{displayName}”?",
    "You can archive this conversation instead." : "Puoi invece archiviare questa conversazione.",
    "Leave conversation" : "Lascia la conversazione",
    "You need to promote a new moderator before you can leave the conversation" : "Devi promuovere un nuovo moderatore prima di poter lasciare la conversazione.",
    "Delete conversation" : "Elimina conversazione",
    "Do you really want to delete \"{displayName}\"?" : "Vuoi davvero eliminare \"{displayName}\"?",
    "Error while deleting conversation" : "Errore durante l'eliminazione della conversazione",
    "Delete all chat messages" : "Elimina tutti i messaggi di chat",
    "Do you really want to delete all messages in \"{displayName}\"?" : "Vuoi davvero eliminare tutti i messaggi in \"{displayName}\"?",
    "Error while clearing chat history" : "Errore durante la cancellazione della cronologia chat",
    "Be careful, these actions cannot be undone." : "Fai attenzione, queste azioni non possono essere annullate.",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Una volta terminata una conversazione, per rientrare in una conversazione chiusa, è necessario un invito. È possibile riprendere una conversazione aperta in qualsiasi momento.",
    "Permanently delete this conversation." : "Elimina definitivamente questa conversazione.",
    "Delete chat messages" : "Elimina i messaggi di chat",
    "Permanently delete all the messages in this conversation." : "Elimina definitivamente tutti i messaggi di questa conversazione.",
    "_%n hour_::_%n hours_" : ["%n ora","%n ore","%n ore"],
    "_%n day_::_%n days_" : ["%n giorno","%n giorni","%n giorni"],
    "_%n week_::_%n weeks_" : ["%n settimana","%n settimane","%n settimane"],
    "Custom expiration time" : "Ora di scadenza personalizzata",
    "Message expiration disabled" : "Scadenza dei messaggi disabilitata",
    "Message expiration set: {duration}" : "Scadenza dei messaggi: {duration}",
    "Error when trying to set message expiration" : "Errore durante l'impostazione della scadenza del messaggio",
    "Message expiration" : "Imposta la scadenza dei messaggi",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "I messaggi di chat possono scadere dopo un certo periodo di tempo. Nota: I file condivisi in chat non saranno eliminati per il proprietario, ma non saranno più condivisi nella conversazione.",
    "Set message expiration" : "Imposta scadenza dei messaggi",
    "Current message expiration" : "Attuale scadenza dei messaggi",
    "Password copied to clipboard" : "Password copiata negli appunti",
    "Password could not be copied" : "La password non può essere copiata",
    "Guest access" : "Accesso ospiti",
    "Breakout rooms are not allowed in public conversations." : "Le sessioni secondarie non sono ammesse nelle conversazioni pubbliche.",
    "Allow guests to join this conversation via link" : "Permetti agli ospiti di unirsi alla conversazione via collegamento",
    "Password protection" : "Protezione con password",
    "This conversation is password-protected. Guests need password to join" : "Questa conversazione è protetta da password. Gli ospiti devono disporre della password per partecipare.",
    "Password protection is needed for public conversations" : "È necessaria la protezione con password per le conversazioni pubbliche",
    "Set a password" : "Imposta una password",
    "Change password" : "Modifica password",
    "Enter new password" : "Inserisci nuova password",
    "Save password" : "Salva la password",
    "Copy password" : "Copia password",
    "Guests are allowed to join this conversation via link" : "Gli ospiti possono partecipare alla conversazione tramite collegamento.",
    "Guests are not allowed to join this conversation" : "Gli ospiti non possono partecipare a questa conversazione.",
    "Resend invitations" : "Nuovo invio degli inviti",
    "This conversation is open to both registered users and users created with the Guests app" : "Questa conversazione è aperta sia agli utenti registrati che agli utenti creati con l'app Ospiti.",
    "This conversation is open to registered users" : "Questa conversazione è aperta agli utenti registrati",
    "This conversation is limited to the current participants" : "Questa conversazione è limitata ai partecipanti attuali",
    "You opened the conversation to both registered users and users created with the Guests app" : "Hai aperto la conversazione sia agli utenti registrati che agli utenti creati con l'applicazione Ospiti.",
    "Error occurred when opening or limiting the conversation" : "Si è verificato un errore durante l'apertura o la limitazione della conversazione",
    "Open conversation to registered users, showing it in search results" : "Apri la conversazione agli utenti registrati, mostrandoli tra i risultati di ricerca",
    "Also open to users created with the Guests app" : "Aperto anche agli utenti creati con l'app Ospiti",
    "Open conversation" : "Apri conversazione",
    "Set language spoken in calls" : "Imposta la lingua parlata nelle chiamate",
    "Languages could not be loaded" : "La lingua non può essere caricata",
    "Loading languages …" : "Caricamento lingue …",
    "Invalid language" : "Lingua non valida",
    "Default language (English)" : "Lingua predefinita (Inglese)",
    "Default live transcription language set" : "Lingua predefinita per la trascrizione in tempo reale",
    "Live transcription language set: {languageName}" : "Lingua per la trascrizione in tempo reale: {languageName}",
    "Error when trying to set live transcription language" : "Errore durante il tentativo di impostare la lingua della trascrizione in tempo reale",
    "Start time: {date}" : "Ora di inizio: {date} ",
    "Start time has been updated" : "L'orario di inizio è stato aggiornato",
    "Error occurred while updating start time" : "Si è verificato un errore durante l'aggiornamento dell'orario di inizio",
    "Enabling the lobby will remove non-moderators from the ongoing call." : "Abilitando la lobby, i non moderatori verranno rimossi dalla chiamata in corso.",
    "Enable lobby, restricting the conversation to moderators" : "Abilita la lobby, limitando la conversazione ai moderatori",
    "Meeting start time" : "Orario di inizio della riunione",
    "Start time (optional)" : "Ora iniziale (facoltativa)",
    "Import email participants" : "Importa email dei partecipanti",
    "You can import a list of email participants from a CSV file." : "È possibile importare un elenco di  e-mail dei partecipanti da un file CSV.",
    "Poll drafts" : "Bozze dei sondaggi",
    "Browse poll drafts" : "Sfoglia bozze dei sondaggi",
    "Error occurred when locking the conversation" : "Si è verificato un errore durante il blocco della conversazione",
    "Error occurred when unlocking the conversation" : "Si è verificato un errore durante lo sblocco della conversazione",
    "Lock conversation" : "Blocca conversazione",
    "This will also terminate the ongoing call." : "Ciò terminerà la chiamata in corso.",
    "Lock the conversation to prevent anyone to post messages or start calls" : "Blocca la conversazione per evitare che qualcuno pubblichi messaggi o inizi una call.",
    "Edit" : "Modifica",
    "More information" : "Altre informazioni",
    "Delete" : "Elimina",
    "Add new bridged channel to current conversation" : "Abilita nuovo canale collegato alla conversazione attuale",
    "unknown state" : "stato sconosciuto",
    "running" : "in esecuzione",
    "not running, check Matterbridge log" : "non in esecuzione, controlla il log di Matterbridge",
    "not running" : "non in esecuzione",
    "Bridge saved" : "Collegamento salvato",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "Puoi collegare canali da vari sistemi di messaggistica istantanea con Matterbridge.",
    "More info on Matterbridge" : "Ulteriori informazioni su Matterbridge",
    "Messaging systems" : "Sistemi di messaggistica",
    "Enable bridge" : "Abilita collegamento",
    "Show Matterbridge log" : "Mostra il log di Matterbridge",
    "Log content" : "Contenuto dei log",
    "Only moderators are allowed to mention @all" : "Solo i moderatori possono menzionare @all",
    "All participants are allowed to mention @all" : "Tutti i partecipanti possono menzionare @all",
    "Participants are now allowed to mention @all." : "I partecipanti possono ora menzionare @all.",
    "Mentioning @all has been limited to moderators." : "La menzione @all è stata limitata ai moderatori.",
    "Allow participants to mention @all" : "Consenti ai partecipanti di menzionare @all",
    "Mention permissions" : "Permessi di menzione",
    "Notifications" : "Notifiche",
    "Notify about calls in this conversation" : "Notifica delle chiamate in questa conversazione",
    "Important conversation" : "Conversazione importante",
    "\"Do not disturb\" user status is ignored for important conversations" : "Lo stato utente “Non disturbare” viene ignorato per le conversazioni importanti.",
    "Sensitive conversation" : "Conversazione delicata",
    "Message preview will be disabled in conversation list and notifications" : "L'anteprima dei messaggi sarà disabilitata nell'elenco delle conversazioni e nelle notifiche.",
    "Recording consent is required for calls in this conversation" : "Per le chiamate incluse in questa conversazione è necessario il consenso alla registrazione.",
    "Recording consent is not required for calls in this conversation" : "Non è necessario il consenso alla registrazione per le chiamate in questa conversazione.",
    "Recording consent requirement was updated" : "È stato aggiornato il requisito relativo al consenso alla registrazione.",
    "Error occurred while updating recording consent" : "Si è verificato un errore durante l'aggiornamento del consenso alla registrazione",
    "Recording Consent" : "Consenso registrazione",
    "Recording consent cannot be changed once a call or breakout session has started." : "Il consenso alla registrazione non può essere modificato una volta avviata una chiamata o una sessione secondaria.",
    "Require recording consent before joining call in this conversation" : "Richiedi il consenso alla registrazione prima di partecipare alla chiamata in questa conversazione",
    "Recording consent is required for all calls" : "Il permesso di registrazione è richiesto per tutte le call",
    "SIP dial-in is now possible without PIN requirement" : "Ora è possibile effettuare la connessione SIP senza PIN",
    "SIP dial-in is now enabled" : "L'accesso SIP è ora abilitato",
    "SIP dial-in is now disabled" : "L'accesso SIP è ora disabilitato",
    "Error occurred when enabling SIP dial-in" : "Si è verificato un errore durante l'abilitazione dell'accesso SIP",
    "Error occurred when disabling SIP dial-in" : "Si è verificato un errore durante la disabilitazione dell'accesso SIP",
    "Phone and SIP dial-in" : "Telefono e connessione SIP",
    "Enable phone and SIP dial-in" : "Abilita telefono e connessione SIP",
    "Allow to dial-in without a PIN" : "Consenti l'accesso senza PIN",
    "Ongoing" : "In corso",
    "{dayPrefix} {dateTime}" : "{dayPrefix} {dateTime}",
    "_%n person accepted_::_%n people accepted_" : ["%n persona ha accettato","%n persone hanno accettato","%n persone hanno accettato"],
    "_%n person declined_::_%n people declined_" : ["%n persona ha rifiutato","%n persone hanno rifiutato","%n persone hanno rifiutato"],
    "_and %n other attachment_::_and %n other attachments_" : ["e %n altro allegato","e altri %n allegati","e altri %n allegati"],
    "With {displayName}" : "Con {displayName}",
    "In {conversation}" : "In {conversation}",
    "View attachment" : "Mostra allegati",
    "Join" : "Partecipa",
    "View conversation" : "Mostra conversazione",
    "View event on Calendar" : "Mostra eventi nel Calendario",
    "Error while creating the conversation" : "Errore durante la creazione della conversazione",
    "Hello, {displayName}" : "Ciao, {displayName}",
    "Start meeting now" : "Avvia meeting ora",
    "Give your meeting a title" : "Dai un titolo al tuo meeting",
    "Create and copy link" : "Crea e copia collegamento",
    "Create a new conversation" : "Crea una nuova conversazione",
    "Join open conversations" : "Entra nelle conversazioni aperte",
    "Call a phone number" : "Chiama un numero di telefono",
    "Scroll backward" : "Scorri indietro",
    "Scroll forward" : "Scorri avanti",
    "Schedule meetings" : "Programma meeting",
    "You don't have any upcoming meetings" : "Non hai nessun prossimo meeting",
    "Open calendar" : "Apri calendario",
    "Unread mentions" : "Menzioni non lette",
    "Messages where you were mentioned will show up here. You can mention people by typing @ followed by their name" : "I messaggi in cui sei stato menzionato verranno visualizzati qui. Puoi menzionare le persone digitando @ seguito dal loro nome.",
    "Upcoming reminders" : "Prossimi promemoria",
    "Message reminders" : "Promemoria messaggi",
    "Set a reminder on a message to be notified" : "Imposta un promemoria su un messaggio per ricevere una notifica",
    "Start a group conversation" : "Avvia una conversazione di gruppo",
    "Create conversation" : "Crea conversazione",
    "Enter your name" : "Digita il tuo nome",
    "Submit name and join" : "Inserisci un nome ed entra",
    "Do you already have an account?" : "Hai già un account?",
    "Log in" : "Login",
    "Error while verifying uploaded file" : "Errore durante la verifica del file caricato",
    "Uploaded file is verified" : "Il file caricato è verificato",
    "Content format is comma-separated values (CSV):<br/>- Header line is required and must match <samp>\"name\",\"email\"</samp> or just <samp>\"email\"</samp><br/>- One entry per line (e.g. <samp>\"John Doe\",\"john@example.tld\"</samp>)" : "Il formato dei contenuti è CSV (valori separati da virgola): <br/>- La riga di intestazione è obbligatoria e deve corrispondere a <samp>\"nome\", \"e-mail\"</samp> o semplicemente <samp>\"e-mail\"</samp><br/>- Una voce per riga (ad esempio <samp>\"John Doe\", \"john@example.tld\"</samp>)",
    "Participants added successfully" : "Partecipanti aggiunti con successo",
    "Error while adding participants" : "Errore durante l'aggiunta dei partecipanti",
    "Import a file" : "Importa un file",
    "Browse" : "Sfoglia",
    "Verifying uploaded file …" : "Verifica del file caricato …",
    "This might take a moment" : "Potrebbe volerci un attimo.",
    "Send invitations" : "Invia inviti",
    "_%n invalid email_::_%n invalid emails_" : ["%n email non valida","%n email non valide","%n email non valide"],
    "_%n email is already imported or a duplicate_::_%n emails are already imported or duplicates_" : ["%n e-mail è già stata importata o è duplicata","%n e-mail sono già state importate o sono duplicate","%n e-mail sono già state importate o sono duplicate"],
    "_%n invitation can be sent_::_%n invitations can be sent_" : ["%n invito può essere inviato","%n inviti possono essere inviati","%n inviti possono essere inviati"],
    "An error occurred while calling a phone number" : "Si è verificato un errore durante la chiamata a un numero di telefono",
    "Phone number could not be called: {error}" : "Impossibile chiamare il numero di telefono: {error}",
    "Phone number could not be called" : "Il numero di telefono non può essere chiamato",
    "Search participants or phone numbers" : "Cerca partecipanti o numeri di telefono",
    "Creating the conversation …" : "Sto creando la conversazione …",
    "Mark as read" : "Marca come letto",
    "Mark as unread" : "Marca come non letto",
    "Remove from favorites" : "Rimuovi dai preferiti",
    "Add to favorites" : "Aggiungi ai preferiti",
    "Unarchive conversation" : "Recupera la conversazione dall'archivio",
    "Ignore \"Do not disturb\"" : "Ignora \"Non disturbare\"",
    "You need to promote a new moderator before you can leave the conversation." : "Devi promuovere un nuovo moderatore prima di poter abbandonare la conversazione. ",
    "Conversation actions" : "Azioni delle conversazioni",
    "Notify about calls" : "Notifica riguardo chiamate",
    "Hide message text" : "Nascondi messaggio di testo",
    "Pending invitations" : "Inviti in attesa",
    "From {user} at {remoteServer}" : "Da {user} su {remoteServer}",
    "Decline invitation" : "Rifiuta invito",
    "Accept invitation" : "Accetta invito",
    "No pending invitations" : "Nessun invito in attesa",
    "Home" : "Home",
    "Unread" : "Da leggere",
    "Mentions" : "Citazioni",
    "Meetings" : "Meetings",
    "Alphabetically" : "Ordine alfabetico",
    "No followed threads" : "Nessun argomento seguito",
    "No matches found" : "Nessuna corrispondenza trovata",
    "No conversations found" : "Nessuna conversazione trovata",
    "You have no archived conversations." : "Non hai conversazioni archiviate",
    "Subscribe to an existing thread or start your own." : "Iscriviti a un argomento esistente o avviane uno nuovo.",
    "You have no unread mentions." : "Non hai menzioni non lette.",
    "You have no unread messages." : "Non hai messaggi non letti.",
    "An error occurred while performing the search" : "Si è verificato un errore durante l'esecuzione della ricerca",
    "Conversation list" : "Elenco delle conversazioni",
    "Filter conversations by" : "Filtra conversazioni per",
    "Unread messages" : "Messaggi non letti",
    "Meeting conversations" : "Conversazioni dei meeting",
    "Clear filters" : "Pulisci filtri",
    "New personal note" : "Nuova nota personale",
    "Back to conversations" : "Torna alle conversazioni",
    "Archived conversations" : "Conversazioni archiviate",
    "Threads" : "Argomenti",
    "Clear filter" : "Pulisci il filtro",
    "Show more threads" : "Mostra altri argomenti",
    "App settings" : "Impostazioni applicazione",
    "Users" : "Utenti",
    "Groups" : "Gruppi",
    "Teams" : "Team",
    "Federated users" : "Utenti federati",
    "New private conversation" : "Nuova conversazione privata",
    "Other sources" : "Altre fonti",
    "Open conversations" : "Apri conversazioni",
    "No search results" : "Nessun risultato di ricerca",
    "Users, groups and teams" : "Utenti, gruppi e teams",
    "Users and groups" : "Utenti e gruppi",
    "Users and teams" : "Utenti e teams",
    "Groups and teams" : "Gruppi e teams",
    "New group conversation" : "Nuova conversazione di gruppo",
    "The meeting will start soon" : "La riunione inizierà presto",
    "This meeting is scheduled for {startTime}" : "Questa riunione è programmata per {startTime}",
    "You are currently waiting in the lobby" : "Stai attualmente aspettando nell'ingresso",
    "Select microphone" : "Seleziona microfono",
    "No microphone available" : "Nessun microfono disponibile",
    "Select speaker" : "Seleziona altoparlante",
    "No speaker available" : "Nessun altoparlante disponibile",
    "Select camera" : "Seleziona fotocamera",
    "No camera available" : "Nessuna fotocamera disponibile",
    "Select a device" : "Seleziona un dispositivo",
    "Playing …" : "Riproduco …",
    "Test speakers" : "Testa altoparlante",
    "Test" : "Prova",
    "Devices" : "Dispositivi",
    "Backgrounds" : "Sfondi",
    "No audio" : "Nessun audio",
    "No camera" : "Nessuna fotocamera",
    "Display video as you will see it (mirrored)" : "Visualizza il video così come lo vedrai (riflesso)",
    "Display video as others will see it" : "Visualizza il video così come lo vedranno gli altri",
    "Calls are not supported in your browser" : "Le chiamate non sono supportate dal tuo browser",
    "Access to microphone is only possible with HTTPS" : "L'accesso a microfono è possibile solo con HTTPS",
    "Access to microphone was denied" : "L'accesso al microfono è stato negato",
    "Error while accessing microphone" : "Errore durante l'accesso al microfono",
    "Access to camera is only possible with HTTPS" : "L'accesso alla fotocamera è possibile solo con HTTPS",
    "The call is being recorded." : "La chiamata viene registrata.",
    "The call might be recorded." : "La chiamata potrebbe essere registrata.",
    "The recording might include your voice, video from camera, and screen share. Your consent is required before joining the call." : "La registrazione potrebbe includere la tua voce, il video dalla telecamera e la condivisione dello schermo. Prima di partecipare alla chiamata è necessario il tuo consenso.",
    "Give consent to the recording of this call" : "Acconsentire alla registrazione di questa chiamata",
    "Show more info" : "Mostra altre info",
    "Audio is not available" : "Audio non disponibile",
    "Video is not available" : "Video non disponibile",
    "Start recording immediately with the call" : "Avvia subito la registrazione della chiamata",
    "Notify all participants about this call" : "Notifica tutti i partecipanti di questa chiamata",
    "Apply settings" : "Applica impostazioni",
    "Select virtual office background" : "Seleziona sfondo virtuale dell'ufficio",
    "Select virtual home background" : "Seleziona sfondo virtuale della casa",
    "Select virtual abstract background" : "Seleziona sfondo virtuale astratto",
    "Select virtual beach background" : "Seleziona sfondo virtuale della spiaggia",
    "Select virtual park background" : "Seleziona sfondo virtuale del parco",
    "Select virtual theater background" : "Seleziona sfondo virtuale del teatro",
    "Select virtual library background" : "Seleziona sfondo virtuale della libreria",
    "Select virtual space station background" : "Seleziona sfondo virtuale della stazione spaziale",
    "Error while uploading the file" : "Errore durante il caricamento del file",
    "Select a file" : "Seleziona un file",
    "Invalid path selected" : "Percorso selezionato non valido",
    "Select virtual background from file {fileName}" : "Seleziona sfondo virtuale dal file {fileName}",
    "Blur" : "Sfocatura",
    "Upload" : "Carica",
    "Files" : "File",
    "(editing)" : "(modificando)",
    "(edited)" : "(modificato)",
    "The message has expired or has been deleted" : "Il messaggio è scaduto o è stato cancellato.",
    "Cancel quote" : "Annulla citazione",
    "24 hours" : "24 ore",
    "7 days" : "7 giorni",
    "30 days" : "30 giorni",
    "Clear reminder – {timeLocale}" : "Cancella promemoria – {timeLocale}",
    "Edited by {actor}" : "Modificato da {actor}",
    "Message text copied to clipboard" : "Testo del messaggio copiato negli appunti",
    "Message text could not be copied" : "Impossibile copiare il testo del messaggio",
    "Message forwarded to \"Note to self\"" : "Messaggio inoltrato a \"Nota a me stesso\"",
    "Error while forwarding message to \"Note to self\"" : "Errore durante l'inoltro del messaggio a \"Nota a me stesso\"",
    "A reminder was successfully removed" : "Un promemoria è stato rimosso con successo.",
    "Error occurred when removing a reminder" : "Si è verificato un errore durante la rimozione di un promemoria",
    "A reminder was successfully set at {datetime}" : "Il promemoria è stato impostato con successo alle {datetime}",
    "Error occurred when creating a reminder" : "Si è verificato un errore durante la creazione di un promemoria",
    "Add a reaction to this message" : "Aggiungi una reazione a questo messaggio",
    "Reply" : "Rispondi",
    "More actions" : "Altre azioni",
    "Set reminder" : "Imposta promemoria",
    "Reply privately" : "Rispondi privatamente",
    "Edit message" : "Modifica messaggio",
    "Copy message" : "Copia messaggio",
    "Copy message link" : "Copia collegamento del messaggio",
    "Go to file" : "Vai al file",
    "Download file" : "Scarica file",
    "Go to thread" : "Vai all'argomento",
    "Edit thread details" : "Modifica dettagli argomento",
    "Forward message" : "Messaggio inoltrato",
    "Translate" : "Traduci",
    "Set custom reminder" : "Imposta promemoria personalizzato",
    "Close reactions menu" : "Chiudi menu reazioni",
    "React with {emoji}" : "Reagisci con {emoji}",
    "React with another emoji" : "Reagisci con un'altra emoji",
    "Choose a conversation to forward the selected message." : "Seleziona una conversazione per inoltrare il messaggio selezionato.",
    "Error while forwarding message" : "Errore durante l'inoltro del messaggio",
    "The message has been forwarded to {selectedConversationName}" : "Il messaggio è stato inoltrato a {selectedConversationName}",
    "Dismiss" : "Annulla",
    "Go to conversation" : "Vai alla conversazione",
    "Detect language" : "Rileva lingua",
    "The message could not be translated" : "Questo messaggio non può essere tradotto",
    "Translation copied to clipboard" : "Traduzione copiata negli appunti",
    "Translation could not be copied" : "Impossibile copiare la traduzione",
    "Translate message" : "Traduci messaggio",
    "Source language to translate from" : "Lingua di partenza da cui tradurre",
    "Translate from" : "Traduci da",
    "Target language to translate into" : "Lingua di destinazione in cui tradurre",
    "Translate to" : "Traduci in",
    "Translating" : "Sto traducendo",
    "Copy translated text" : "Copia testo tradotto",
    "Send now" : "Spedisci ora",
    "Message read by everyone who shares their reading status" : "Messaggio letto da tutti coloro che condividono il proprio stato di lettura",
    "Message sent" : "Messaggio inviato",
    "Sent without notification" : "Invia senza notificare",
    "Deleting message" : "Eliminazione del messaggio",
    "Message deleted successfully, but a bot or Matterbridge is configured and the message might already be distributed to other services" : "Messaggio eliminato correttamente, ma è configurato un bot o Matterbridge e il messaggio potrebbe essere già stato distribuito ad altri servizi.",
    "Message deleted successfully" : "Messaggio eliminato correttamente",
    "Message could not be deleted because it is too old" : "Impossibile eliminare il messaggio perché è troppo datato",
    "Only normal chat messages can be deleted" : "È possibile eliminare solo i normali messaggi di chat",
    "An error occurred while deleting the message" : "Si è verificato un errore durante l'eliminazione del messaggio",
    "Your browser does not support playing audio files" : "Il tuo browser non supporta la riproduzione di file audio",
    "Contact" : "Contatto",
    "{stack} in {board}" : "{stack} in {board}",
    "Deck Card" : "Scheda di Deck",
    "Remove {fileName}" : "Rimuovi {fileName}",
    "Open this location in OpenStreetMap" : "Apri questa posizione in OpenStreetMap",
    "_%n reply_::_%n replies_" : ["%n risposta","%n risposte","%n risposte"],
    "Sending message" : "Invio del messaggio",
    "Failed to send the message. Click to try again" : "Invio del messaggio non riuscito. Fare clic per riprovare",
    "Not enough free space to upload file" : "Spazio libero insufficiente per caricare il file",
    "You cannot send messages to this conversation at the moment" : "Non puoi inviare messaggi in questa conversazione al momento",
    "Could not update the message" : "Impossibile aggiornare il messaggio",
    "You voted" : "Hai votato",
    "_Poll draft • %n option_::_Poll draft • %n options_" : ["Bozza del sondaggio • %n opzione","Bozza del sondaggio • %n opzioni","Bozza del sondaggio • %n opzioni"],
    "_%n vote_::_%n votes_" : ["%n voto","%n voti","%n voti"],
    "Edit poll draft" : "Modifica bozza del sondaggio",
    "Delete poll draft" : "Elimina bozza del sondaggio",
    "Open poll" : "Apri sondaggio",
    "See results" : "Vedi risultati",
    "Reactions" : "Reazioni",
    "No permission to post reactions in this conversation" : "Non è consentito pubblicare reazioni in questa conversazione.",
    "and {participant}" : "e {participant}",
    "_and %n other participant_::_and %n other participants_" : ["e %n altro partecipante","e altri %n partecipanti","e altri %n partecipanti"],
    "Show all reactions" : "Mostra tutte le reazioni",
    "Add more reactions" : "Aggiungi più reazioni",
    "Show or collapse system messages" : "Mostra o nascondi i messaggi di sistema",
    "No messages" : "Nessun messaggio",
    "All messages have expired or have been deleted." : "Tutti i messaggi sono scaduti o sono stati cancellati.",
    "Unpin" : "Rimuovi",
    "Cancel search" : "Annulla ricerca",
    "Add a phone number" : "Aggiungi numero di telefono",
    "Error: A password is required to create the conversation." : "Errore: per creare la conversazione è necessaria una password.",
    "All set, the conversation \"{conversationName}\" was created." : "Tutto pronto, la conversazione \"{conversationName}\" è stata creata.",
    "Create a new group conversation" : "Crea una nuova conversazione di gruppo",
    "Add participants" : "Aggiungi partecipanti",
    "Maximum length exceeded ({maxlength} characters)" : "Lunghezza massima superata ({maxlength} caratteri)",
    "Conversation visibility" : "Visibilità della conversazione",
    "Allow guests to join via link" : "Consenti agli ospiti di partecipare tramite collegamento",
    "Enter password" : "Digita la password",
    "This conversation has been locked" : "Questa conversazione è stata bloccata",
    "No permission to post messages in this conversation" : "Nessun permesso per pubblicare messaggi in questa conversazione",
    "Joining conversation …" : "Partecipazione alla conversazione...",
    "Write a message without notification" : "Scrivi un messaggio senza notifica",
    "Create a thread silently" : "Crea un argomento silenzioso",
    "Create a thread" : "Crea un argomento",
    "Send message silently" : "Invia messaggio direttamente",
    "Send message" : "Invia messaggio",
    "Send without notification" : "Invia messaggio senza notifica",
    "The participant will not be notified about new messages" : "Il partecipante non riceverà notifiche relative ai nuovi messaggi.",
    "Participants will not be notified about new messages" : "I partecipanti non saranno avvisati dei nuovi messaggi",
    "Thread title is required" : "Il titolo dell'argomento è obbligatorio",
    "Message text is required" : "Il testo del messaggio è obbligatorio",
    "The message could not be edited" : "Il messaggio non può essere modificato",
    "File to share" : "File da condividere",
    "File upload is not available in this conversation" : "Il caricamento dei file non è disponibile in questa conversazione.",
    "Add emoji" : "Aggiungi emoji",
    "Adding a mention will only notify users who did not read the message." : "L'aggiunta di una menzione notificherà solo gli utenti che non hanno letto il messaggio.",
    "Thread title" : "Titolo dell'argomento",
    "Send later" : "Invia più tardi",
    "Cancel editing" : "Annulla modifica",
    "{user} is out of office and might not respond." : "{user} è fuori ufficio e potrebbe non rispondere.",
    "Absence period: {startDate} - {endDate}" : "Periodo di assenza: {startDate} - {endDate}",
    "Replacement:" : "Sostituzione:",
    "Share from {nextcloud}" : "Condividi da {nextcloud}",
    "Share from Files" : "Condividi da File",
    "Share files to the conversation" : "Condividi file nella conversazione",
    "Upload from device" : "Carica dal dispositivo",
    "Create new poll" : "Crea nuovo sondaggio",
    "Smart picker" : "Selettore intelligente",
    "Record voice message" : "Registra messaggio vocale",
    "End recording and send" : "Termina la registrazione e invia",
    "Dismiss recording" : "Annulla la registrazione",
    "Access to the microphone was denied" : "L'accesso al microfono è stato negato",
    "Microphone either not available or disabled in settings" : "Microfono non disponibile o disabilitato nelle impostazioni",
    "Error while recording audio" : "Errore durante la registrazione dell'audio",
    "Generating summary of unread messages …" : "Generando il riassunto dei messaggi non letti …",
    "Summary is AI generated and might contain mistakes" : "Il riassunto è generato dall'IA e può contenere errori.",
    "Error occurred during a summary generation" : "Si è verificato un errore durante la generazione del riassunto",
    "New file" : "Nuovo file",
    "Blank" : "Vuoto",
    "Error while creating file" : "Errore durante la creazione del file",
    "Create and share a new file" : "Crea e condividi un nuovo file",
    "Name of the new file" : "Nome del nuovo file",
    "Create file" : "Crea file",
    "Someone is typing …" : "Qualcuno sta scrivendo …",
    "{user1} is typing …" : "{user1} sta scrivendo …",
    "{user1} and {user2} are typing …" : "{user1} e {user2} stanno scrivendo …",
    "{user1}, {user2} and {user3} are typing …" : "{user1}, {user2} e {user3} stanno scrivendo …",
    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["{user1}, {user2}, {user3} e %n altro stanno scrivendo …","{user1}, {user2}, {user3} e %n altri stanno scrivendo …","{user1}, {user2}, {user3} e %n altri stanno scrivendo …"],
    "Add more files" : "Aggiungi altri file",
    "Send" : "Invia",
    "In this conversation <strong>{user}</strong> can:" : "In questa conversazione <strong>{utente}</strong> può:",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "Modifica i permessi predefiniti per i partecipanti a <strong> {conversationName}</strong>",
    "Start a call" : "Inizia la chiamata",
    "Skip the lobby" : "Salta la sala d'attesa",
    "Can post messages and reactions" : "Può pubblicare messaggi e reazioni",
    "Enable the microphone" : "Accendi il microfono",
    "Enable the camera" : "Abilita la fotocamera",
    "Share the screen" : "Condividi lo schermo",
    "Update permissions" : "Aggiorna i permessi",
    "Updating permissions" : "Aggiornamento dei permessi",
    "No poll drafts" : "Nessuna bozza di sondaggio",
    "There is no poll drafts yet saved for this conversation" : "Non ci sono ancora bozze di sondaggi salvate per questa conversazione.",
    "Create poll in {name}" : "Crea sondaggio in {name}",
    "Create poll" : "Crea sondaggio",
    "Error while importing poll" : "Errore durante l'importazione del sondaggio",
    "Question" : "Domanda",
    "Ask a question" : "Fai una domanda",
    "Import draft from file" : "Importa bozza da file",
    "Answers" : "Risposte",
    "Answer {option}" : "Rispondi {option}",
    "Delete poll option" : "Elimina opzione del sondaggio",
    "Add answer" : "Aggiungi risposta",
    "Settings" : "Impostazioni",
    "Anonymous poll" : "Sondaggio anonimo",
    "Multiple answers" : "Risposta multipla",
    "Save as draft" : "Salva come bozza",
    "Export draft to file" : "Esporta bozza su file",
    "You voted for this option" : "Hai votato questa opzione",
    "End poll" : "Termina sondaggio",
    "Change your vote" : "Cambia il tuo voto",
    "Results" : "Risultati",
    "Voted participants" : "Partecipanti che hanno votato",
    "Send a message to \"{roomName}\"" : "Invia messaggio a \"{roomName}\"",
    "Hide list of participants" : "Cambia lista dei partecipanti",
    "Show list of participants" : "Mostra lista dei partecipanti",
    "Assistance requested in {roomName}" : "Assistenza richiesta su {roomName}",
    "The message was sent to \"{roomName}\"" : "Il messaggio è stato inviato su \"{roomName}\"",
    "Dismiss request for assistance" : "Togli richiesta di assistenza",
    "Send message to room" : "Invia messaggio nella stanza",
    "Back to main room" : "Torna alla stanza principale",
    "Back to your room" : "Torna alla tua stanza",
    "Message all rooms" : "Invia a tutte le stanze",
    "Start session" : "Avvia sessione",
    "Start a call before you start a breakout room session" : "Avvia una chiamata prima di avviare una sessione secondaria",
    "Stop session" : "Termina sessione",
    "The message was sent to all breakout rooms" : "Il messaggio è stato inviato a tutte le sessioni secondarie.",
    "Send a message to all breakout rooms" : "Invia un messaggio a tutte le sessioni secondarie",
    "Breakout rooms are not started" : "Le sessioni secondarie non sono avviate",
    "Calls without High-performance backend can cause connectivity issues and high load on devices. {linkstart}Learn more{linkend}" : "Le chiamate senza un backend ad alte prestazioni possono causare problemi di connettività e un carico elevato sui dispositivi. {linkstart}Ulteriori informazioni{linkend}",
    "Talk setup incomplete" : "Configurazione di Talk incompleta",
    "Disable lobby" : "Disabilita l'ingresso",
    "Settings for participant \"{user}\"" : "Impostazioni per il partecipante \"{user}\"",
    "Participant \"{user}\"" : "Partecipante \"{user}\"",
    "moderator" : "moderatore",
    "bot" : "bot",
    "guest" : "ospite",
    "Ringing …" : "Sta squillando …",
    "Call rejected" : "Chiamata rifiutata",
    "{time} talking …" : "{time} in conversazione...",
    "{time} talking time" : "{time} tempo di conversazione",
    "Raised their hand" : "Hanno alzato la mano",
    "Joined with video" : "Partecipa con video",
    "Joined via phone" : "Partecipa tramite telefono",
    "Joined with audio" : "Partecipa con audio",
    "The text must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "Il testo deve contenere un numero di caratteri inferiore o uguale a {maxLength} . Il testo attuale contiene {charactersCount} caratteri",
    "Remove group and members" : "Rimuovi gruppo e membri",
    "Remove team and members" : "Rimuovi team e membri",
    "Remove participant" : "Rimuovi partecipante",
    "Do you really want to remove group \"{displayName}\" and its members from this conversation?" : "Vuoi davvero rimuovere il gruppo \"{displayName}\" e i suoi membri da questa conversazione?",
    "Do you really want to remove team \"{displayName}\" and its members from this conversation?" : "Vuoi davvero rimuovere il team \"{displayName}\" e i suoi membri da questa conversazione?",
    "Do you really want to remove {displayName} from this conversation?" : "Vuoi davvero rimuovere {displayName} da questa conversazione?",
    "Notification was sent to {displayName}" : "La notifica è stata inviata in {displayName}",
    "Could not send notification to {displayName}" : "Impossibile inviare la notifica a {displayName}",
    "Permissions granted to {displayName}" : "Permessi concessi a {displayName}",
    "Could not modify permissions for {displayName}" : "Impossibile modificare i permessi per {displayName}",
    "Permissions removed for {displayName}" : "Permessi rimossi per {displayName}",
    "Permissions set to default for {displayName}" : "Permessi impostati come predefiniti per {displayName}",
    "Phone number could not be hung up" : "Impossibile riagganciare il numero di telefono",
    "Phone number could not be put on hold" : "Impossibile mettere in attesa il numero di telefono",
    "Phone number could not be muted" : "Impossibile mutare il numero di telefono",
    "Phone number could not be unmuted" : "Impossibile riattivare l'audio del numero di telefono",
    "DTMF message could not be sent" : "Impossibile inviare il messaggio DTMF",
    "Phone number copied to clipboard" : "Numero di telefono copiato negli appunti",
    "Phone number could not be copied" : "Impossibile copiare il numero di telefono",
    "in the lobby" : "nella stanza",
    "Dial out phone" : "Telefona",
    "Hang up phone" : "Riaggancia",
    "Move back to lobby" : "Riporta alla lobby",
    "Move to conversation" : "Muovi nella conversazione",
    "Dial-in PIN" : "PIN di accesso",
    "Demote from moderator" : "Declassa da moderatore",
    "Promote to moderator" : "Promuovi a moderatore",
    "Resend invitation" : "Nuovo invio dell'invito",
    "Send call notification" : "Invia notifica di chiamata",
    "Dial out phone number" : "Componi numero di telefono",
    "Resume call for phone number" : "Riprendi chiamata per numero di telefono",
    "Put phone number on hold" : "Metti numero di telefono in attesa",
    "Unmute phone number" : "Riattiva audio del numero di telefono",
    "Mute phone number" : "Muta numero di telefono",
    "Copy phone number" : "Copia numero di telefono",
    "Reset custom permissions" : "Reimposta autorizzazioni personalizzate",
    "Grant all permissions" : "Concedi tutti i permessi",
    "Remove all permissions" : "Rimuovi tutte le autorizzazioni",
    "Also ban from this conversation" : "Bandisci anche da questa conversazione",
    "Internal note (reason to ban)" : "Nota interna (motivo del bando)",
    "Remove" : "Rimuovi",
    "Permissions modified for {displayName}" : "Permessi modificati per {displayName}",
    "Add users, groups or teams" : "Aggiungi utente, gruppo o team",
    "Add users or groups" : "Aggiungi utenti o gruppi",
    "Add users or teams" : "Aggiungi utente o teams",
    "Add users" : "Aggiungi utenti",
    "Add groups or teams" : "Aggiungi gruppo o teams",
    "Add groups" : "Aggiungi gruppi",
    "Add teams" : "Aggiungi teams",
    "Add other sources" : "Aggiungi altre fonti",
    "Add emails" : "Aggiungi email",
    "Integrations" : "Integrazioni",
    "Add federated users" : "Aggiungi utenti federati",
    "Searching …" : "Ricerca in corso...",
    "Search for more users" : "Cerca altri utenti",
    "You can search or add participants via name, email, or Federated Cloud ID" : "È possibile cercare o aggiungere partecipanti tramite nome, e-mail o Federated Cloud ID.",
    "Search or add participants" : "Cerca o aggiungi partecipanti",
    "Invitation was sent to {actorId}" : "Invito inviato a {actorId}",
    "An error occurred while adding the participants" : "Si è verificato un errore durante l'aggiunta dei partecipanti",
    "A new group conversation with selected participant will be created" : "Verrà creata una nuova conversazione di gruppo con i partecipanti selezionati.",
    "Participants" : "Partecipanti",
    "Participants ({count})" : "Partecipanti ({count})",
    "Open chat" : "Apri chat",
    "You have new unread messages in the chat." : "Hai nuovi messaggi non letti nella chat.",
    "You have been mentioned in the chat." : "Sei stato menzionato nella chat.",
    "Search messages" : "Cerca messaggi",
    "Chat" : "Chat",
    "Details" : "Dettagli",
    "Shared items" : "Oggetti condivisi",
    "Search in {name}" : "Cerca in {name}",
    "Threads in {name}" : "Argomenti in {name}",
    "{actor} in {conversation}" : "{actor} in {conversation}",
    "Search messages …" : "Cerca messaggi …",
    "Search options" : "Opzioni di ricerca",
    "From User" : "Dall'utente",
    "Since" : "A partire dal",
    "Until" : "Fino al",
    "No results found" : "Nessun risultato trovato",
    "Load more results" : "Mostra altri risultati",
    "Recent threads" : "Argomenti recenti",
    "Projects" : "Progetti",
    "No shared items" : "Nessun elemento condiviso",
    "Thread notifications" : "Notifiche dagli argomenti",
    "Thread actions" : "Azioni degli argomenti",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Link to a conversation" : "Collega a una conversazione",
    "No open conversations found" : "Nessuna conversazione aperta trovata",
    "Either there are no open conversations or you joined all of them." : "O non ci sono conversazioni aperte oppure ti sei unito a tutte.",
    "Check spelling or use complete words." : "Controlla l'ortografia o usa parole complete.",
    "Search conversations or users" : "Cerca conversazioni o utenti",
    "Select conversation" : "Seleziona conversazione",
    "Number length is not valid" : "La lunghezza del numero non è valida",
    "Region code is not valid" : "Il codice regionale non è valido",
    "Number length is too short" : "La lunghezza del numero è troppo breve",
    "Number length is too long" : "La lunghezza del numero è troppo lunga",
    "Number is not valid" : "Il numero non è valid",
    "Phone numbers" : "Numeri di telefono",
    "Display name: {name}" : "Nome visualizzato: {name}",
    "Edit display name" : "Modifica nome visualizzato",
    "Display name (required)" : "Nome visualizzato (richiesto)",
    "Save name" : "Salva nome",
    "Error while setting personal setting" : "Errore durante l'impostazione delle impostazioni personali",
    "Error while saving sounds setting" : "Errore durante il salvataggio dell'impostazione dei suoni",
    "Play sounds when participants join or leave a call" : "Riproduci suoni quando i partecipanti entrano o abbandonano una chiamata",
    "Notification settings" : "Impostazioni di notifica",
    "Default language" : "Lingua predefinita",
    "Select location for attachments" : "Seleziona la posizione per gli allegati",
    "Error while setting attachment folder" : "Errore durante l'impostazione della cartella degli allegati",
    "Error while setting read status privacy" : "Errore durante l'impostazione della riservatezza dello stato di lettura",
    "Error while setting typing status privacy" : "Errore durante l'impostazione della privacy dello stato di digitazione",
    "Error while setting default media state" : "Errore durante l'impostazione dello stato predefinito dei media",
    "Privacy" : "Riservatezza",
    "Attachments folder" : "Cartella degli allegati",
    "Toggle full screen" : "Attiva schermo intero",
    "Search" : "Cerca",
    "Focus the chat input" : "Attiva la digitazione della chat",
    "Unfocus the chat input to use shortcuts" : "Disattiva la digitazione della chat per utilizzare le scorciatoie",
    "Edit your last message" : "Modifica ultimo messaggio",
    "Shortcuts while in a call" : "Scorciatoie durante una chiamata",
    "Camera on and off" : "Fotocamera attivo e disattivo",
    "Microphone on and off" : "Microfono attivo e disattivo",
    "Raise or lower hand" : "Alza o abbassa la mano",
    "Push to talk or push to mute" : "Premi per parlare o premi per silenziare",
    "Zoom-in / zoom-out a screen share" : "Ingrandisci/riduci una condivisione dello schermo",
    "Mouse wheel" : "Rotella del mouse",
    "Start call silently" : "Avvia chiamata silenziosa",
    "Start call" : "Inizia chiamata",
    "End call" : "Termina chiamata",
    "This call has just ended" : "Questa chiamata è appena terminata",
    "You will be able to join the call only after a moderator starts it." : "Potrai unirti alla chiamata solo dopo che un moderatore l'abbia avviata.",
    "End call for everyone" : "Termina chiamata per tutti",
    "Starting the recording" : "Avvia registrazione",
    "Recording" : "Registrazione",
    "The call has been running for one hour." : "La chiamata è in corso da un'ora.",
    "Cancel recording start" : "Annulla avvio registrazione",
    "Stop recording" : "Termina registrazione",
    "Send a reaction" : "Invia una reazione",
    "React with {reaction}" : "Reagisci con {reaction}",
    "All tasks done!" : "Tutte le attività completate!",
    "_{done} of %n task_::_{done} of %n tasks_" : ["{done} di %n attività","{done} di %n attività","{done} di %n attività"],
    "Add participants to this call" : "Aggiungi partecipanti a questa chiamata",
    "_%n participant in call_::_%n participants in call_" : ["%n partecipante in chiamata","%n partecipanti in chiamata ","%n partecipanti in chiamata"],
    "Scheduled messages" : "Messaggi programmati",
    "You are not allowed to enable screensharing" : "Non sei autorizzato ad abilitare la condivisione dello schermo",
    "No screensharing" : "Nessuna condivisione dello schermo",
    "Screensharing options" : "Opzioni di condivisione dello schermo",
    "Enable screensharing" : "Abilita la condivisione dello schermo",
    "Bad sent video and screen quality." : "Qualità video e dello schermo inviate non corrette.",
    "Bad sent screen quality." : "Qualità dello schermo inviata non corretta.",
    "Bad sent video quality." : "Qualità del video inviata non corretta.",
    "Bad sent audio, video and screen quality." : "Qualità audio, video e dello schermo inviate non corrette.",
    "Bad sent audio and screen quality." : "Qualità audio e dello schermo inviate non corrette.",
    "Bad sent audio and video quality." : "Qualità dell'audio e del video inviate non corrette.",
    "Bad sent audio quality." : "Qualità audio inviata non corretta.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "La tua connessione a Internet o il computer sono occupati e gli altri partecipanti potrebbero non essere in grado di vedere il tuo schermo. Per migliorare la situazione prova, a disabilitare la sfocatura dello sfondo o il tuo video mentre fai una condivisione dello schermo.",
    "Disable background blur" : "Disattiva la sfocatura dello sfondo",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "La tua connessione a Internet o il computer sono occupati e gli altri partecipanti potrebbero non essere in grado di vedere il tuo schermo. Per migliorare la situazione, prova a disabilitare il tuo video durante una condivisione dello schermo.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "La tua connessione a Internet o il computer sono occupati e gli altri partecipanti potrebbero non essere in grado di vedere il tuo schermo.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "La tua connessione a Internet o il computer sono occupati e gli altri partecipanti potrebbero non essere in grado di vederti.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "La tua connessione Internet o il tuo computer sono occupati e gli altri partecipanti potrebbero non essere in grado di capirti e vederti. Per migliorare la situazione, prova a disabilitare la sfocatura dello sfondo o il tuo video durante la condivisione dello schermo.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "La tua connessione a Internet o il computer sono occupati e gli altri partecipanti potrebbero non essere in grado di capirti e vederti. Per migliorare la situazione prova a disabilitare il tuo video durante una condivisione dello schermo.",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "La tua connessione a Internet o il computer sono occupati e gli altri partecipanti potrebbero non essere in grado di capirti e vedere il tuo schermo. Per migliorare la situazione prova a disabilitare la condivisione dello schermo.",
    "Disable screenshare" : "Disabilita la condivisione dello schermo",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "La tua connessione Internet o il tuo computer sono occupati e gli altri partecipanti potrebbero non essere in grado di capirti e vederti. Per migliorare la situazione, prova a disabilitare la sfocatura dello sfondo o il tuo video.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "La tua connessione a Internet o il computer sono occupati e gli altri partecipanti potrebbero non essere in grado di capirti e vedere il tuo schermo. Per migliorare la situazione prova a disabilitare il tuo video.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "La tua connessione a Internet o il computer sono occupati e gli altri partecipanti potrebbero non essere in grado di capirti.",
    "Screen sharing is not supported by your browser." : "La condivisione dello schermo non è supportata dal tuo browser.",
    "Screen sharing requires the page to be loaded through HTTPS." : "La condivisione dello schermo richiede che la pagina sia caricata tramite HTTPS.",
    "Screensharing requires the page to be loaded through HTTPS." : "La condivisione dello schermo richiede che la pagina sia caricata tramite HTTPS.",
    "An error occurred while starting screensharing." : "Si è verificato un errore durante l'avvio della condivisione dello schermo.",
    "Select virtual background" : "Salva sfondo virtuale",
    "Show your screen" : "Mostra il tuo schermo",
    "Stop screensharing" : "Ferma la condivisione dello schermo",
    "Mute others" : "Silenzia gli altri",
    "Start recording" : "Avvia registrazione",
    "Set up breakout rooms" : "Imposta sessioni secondarie",
    "Download attendance list" : "Scarica l'elenco delle presenze",
    "Open Calendar" : "Apri Calendario",
    "Remove participant {name}" : "Rimuovi il partecipante {name}",
    "Would you like to delete this conversation?" : "Vuoi eliminare questa conversazione?",
    "Are you sure you want to delete this conversation?" : "Vuoi davvero eliminare questa conversazione?",
    "Delete now" : "Elimina ora",
    "Keep" : "Mantieni",
    "Open dialpad" : "Apri tastierino numerico",
    "Select a region" : "Seleziona una regione",
    "Local time: {time}" : "Ora locale: {time}",
    "Search …" : "Cerca …",
    "Message without mention" : "Messaggio senza menzione",
    "Mention myself" : "Menziona me stesso",
    "Mention everyone" : "Menziona chiunque",
    "Select a conversation" : "Seleziona una conversazione",
    "Select a mode" : "Seleziona una modalità",
    "You do not have permissions to access this conversation." : "Non hai i permessi per accedere a questa conversazione.",
    "Join a different conversation or start a new one." : "Partecipa a una conversazione diversa o avviane una nuova.",
    "The conversation does not exist" : "La conversazione non esiste",
    "Join a conversation or start a new one!" : "Unisciti a una conversazione o avviane una nuova!",
    "Duplicate session" : "Duplica sessione",
    "Creating and joining a conversation with \"{userid}\"" : "Creare e partecipare a una conversazione con \"{userid}\"",
    "Join a conversation or start a new one" : "Unisciti a una conversazione o avviane una nuova",
    "Error while joining the conversation" : "Errore durante la partecipazione alla conversazione",
    "Nextcloud URL" : "URL Nextcloud",
    "Nextcloud user" : "Utente Nextcloud",
    "User password" : "Password utente",
    "Talk conversation" : "Conversazione di Talk",
    "Skip TLS verification" : "Salta la verifica TLS",
    "Matrix server URL" : "URL server Matrix",
    "User" : "Utente",
    "Matrix channel" : "Canale Matrix",
    "Mattermost server URL" : "URL server Mattermost",
    "Mattermost user" : "Utente Mattermost",
    "Team name" : "Nome squadra",
    "Channel name" : "Nome canale",
    "Rocket.Chat server URL" : "URL server Rocket.Chat",
    "User name or email address" : "Nome utente o indirizzo email",
    "Rocket.Chat channel" : "Canale Rocket.Chat",
    "Zulip server URL" : "URL server Zulip",
    "Bot user name" : "Nome utente del bot",
    "Bot API key" : "Chiave API del bot",
    "Zulip channel" : "Canale Zulip",
    "API token" : "Token API",
    "Slack channel" : "Canale Slack",
    "Server ID or name" : "ID o nome del server",
    "Channel ID (prefixed with \"ID:\") or name" : "ID canale (preceduto da \"ID:\") o nome",
    "Channel" : "Canale",
    "Login" : "Accedi",
    "Chat ID" : "ID chat",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "URL server IRC (ad es. chat.freenode.net:6667)",
    "Nickname" : "Pseudonimo",
    "Connection password" : "Password di connessione",
    "IRC channel" : "Canale IRC",
    "Channel password" : "Password del canale",
    "NickServ nickname" : "Pseudonimo NickServ",
    "NickServ password" : "Password NickServ",
    "Use TLS" : "Usa TLS",
    "Use SASL" : "Usa SASL",
    "Tenant ID" : "ID tenant",
    "Client ID" : "ID client",
    "Team ID" : "ID team",
    "Thread ID" : "ID thread",
    "XMPP/Jabber server URL" : "URL server XMPP/Jabber",
    "MUC server URL" : "URL server MUC",
    "Jabber ID" : "ID Jabber",
    "Media" : "Media",
    "Polls" : "Sondaggi",
    "Deck cards" : "Carte del mazzo",
    "Voice messages" : "Messaggi vocali",
    "Locations" : "Posizioni",
    "Call recordings" : "Registrazioni delle chiamate",
    "Audio" : "Audio",
    "Show all media" : "Mostra tutti i media",
    "Show all files" : "Mostra tutti i file",
    "Show all polls" : "Mostra tutti i sondaggi",
    "Show all deck cards" : "Mostra tutte le carte del mazzo",
    "Show all voice messages" : "Mostra tutti i messaggi vocali",
    "Show all locations" : "Mostra tutte le località",
    "Show all call recordings" : "Mostra tutte le registrazioni delle chiamate",
    "Show all audio" : "Mostra tutto l'audio",
    "Show all other" : "Mostra tutti gli altri",
    "Follow conversation settings" : "Impostazioni delle conversazioni seguite",
    "Group" : "Gruppo",
    "Team" : "Team",
    "You reconnected to the call" : "Ti sei ricollegato alla chiamata",
    "{actor} reconnected to the call" : "{actor} si è riconnesso alla chiamata",
    "You added {user0} and {user1}" : "Hai aggiunto {user0} e {user1}",
    "_You added {user0}, {user1} and %n more participant_::_You added {user0}, {user1} and %n more participants_" : ["Hai aggiunto {user0}, {user1} e %n altro partecipante","Hai aggiunto {user0}, {user1} e %n altri partecipanti","Hai aggiunto {user0}, {user1} e %n altri partecipanti"],
    "An administrator added you and {user0}" : "Un amministratore ha aggiunto te e {user0}",
    "{actor} added you and {user0}" : "{actor} ha aggiunto te e {user0}",
    "_An administrator added you, {user0} and %n more participant_::_An administrator added you, {user0} and %n more participants_" : ["Un amministratore ha aggiunto te, {user0} e %n altro partecipante","Un amministratore ha aggiunto te, {user0} e altri %n partecipanti","Un amministratore ha aggiunto te, {user0} e altri %n partecipanti"],
    "_{actor} added you, {user0} and %n more participant_::_{actor} added you, {user0} and %n more participants_" : ["{actor} ha aggiunto te, {user0} e %n altro partecipante","{actor} ha aggiunto te, {user0} e altri %n partecipanti","{actor} ha aggiunto te, {user0} e altri %n partecipanti"],
    "An administrator added {user0} and {user1}" : "Un amministratore ha aggiunto {user0} e {user1}",
    "{actor} added {user0} and {user1}" : "{actor} ha aggiunto {user0} e {user1}",
    "_An administrator added {user0}, {user1} and %n more participant_::_An administrator added {user0}, {user1} and %n more participants_" : ["Un amministratore ha aggiunto {user0}, {user1} e %n altro partecipante","Un amministratore ha aggiunto {user0}, {user1} e altri %n partecipanti","Un amministratore ha aggiunto {user0}, {user1} e altri %n partecipanti"],
    "_{actor} added {user0}, {user1} and %n more participant_::_{actor} added {user0}, {user1} and %n more participants_" : ["{actor} ha aggiunto {user0}, {user1} e %n altro partecipante","{actor} ha aggiunto {user0}, {user1} e altri %n partecipanti","{actor} ha aggiunto {user0}, {user1} e altri %n partecipanti"],
    "You removed {user0} and {user1}" : "Hai rimosso {user0} e {user1}",
    "_You removed {user0}, {user1} and %n more participant_::_You removed {user0}, {user1} and %n more participants_" : ["Hai rimosso {user0}, {user1} ed %n altro partecipante","Hai rimosso {user0}, {user1} ed altri %n partecipanti","Hai rimosso {user0}, {user1} ed altri %n partecipanti"],
    "An administrator removed you and {user0}" : "Un amministratore ha rimosso te e {user0}",
    "{actor} removed you and {user0}" : "{actor} ha rimosso te e {user0}",
    "_An administrator removed you, {user0} and %n more participant_::_An administrator removed you, {user0} and %n more participants_" : ["Un amministratore ha rimosso te, {user0} e %n altro partecipante","Un amministratore ha rimosso te, {user0} e altri %n partecipanti","Un amministratore ha rimosso te, {user0} e altri %n partecipanti"],
    "_{actor} removed you, {user0} and %n more participant_::_{actor} removed you, {user0} and %n more participants_" : ["{actor} ha rimosso te, {user0} e %n altri partecipanti","{actor} ha rimosso te, {user0} e altri %n partecipanti","{actor} ha rimosso te, {user0} e altri %n partecipanti"],
    "An administrator removed {user0} and {user1}" : "Un amministratore ha rimosso {user0} e {user1}",
    "{actor} removed {user0} and {user1}" : "{actor} ha rimosso {user0} e {user1}",
    "_An administrator removed {user0}, {user1} and %n more participant_::_An administrator removed {user0}, {user1} and %n more participants_" : ["Un amministratore ha rimosso {user0}, {user1} e %n altro partecipante","Un amministratore ha rimosso {user0}, {user1} e altri %n partecipanti","Un amministratore ha rimosso {user0}, {user1} e altri %n partecipanti"],
    "_{actor} removed {user0}, {user1} and %n more participant_::_{actor} removed {user0}, {user1} and %n more participants_" : ["{actor} ha rimosso {user0}, {user1} e %n altro partecipante","{actor} ha rimosso {user0}, {user1} e altri %n partecipanti","{actor} ha rimosso {user0}, {user1} e altri %n partecipanti"],
    "You and {user0} joined the call" : "Tu e {user0} vi siete uniti alla chiamata",
    "_You, {user0} and %n more participant joined the call_::_You, {user0} and %n more participants joined the call_" : ["Tu, {user0} e altro %n partecipante vi siete uniti alla chiamata","Tu, {user0} e %n altri partecipanti vi siete uniti alla chiamata","Tu, {user0} e %n altri partecipanti vi siete uniti alla chiamata"],
    "{user0} and {user1} joined the call" : "{user0} e {user1} si sono uniti alla chiamata",
    "_{user0}, {user1} and %n more participant joined the call_::_{user0}, {user1} and %n more participants joined the call_" : ["{user0}, {user1} e %n altro partecipante si sono uniti alla chiamata","{user0}, {user1} e %n altri partecipanti si sono uniti alla chiamata","{user0}, {user1} e %n altri partecipanti si sono uniti alla chiamata"],
    "You and {user0} left the call" : "Tu e {user0} avete lasciato la chiamata",
    "_You, {user0} and %n more participant left the call_::_You, {user0} and %n more participants left the call_" : ["Tu, {user0} e %n altro partecipante avete abbandonato la chiamata","Tu, {user0} e altri %n partecipanti avete abbandonato la chiamata","Tu, {user0} e altri %n partecipanti avete abbandonato la chiamata"],
    "{user0} and {user1} left the call" : "{user0} e {user1} hanno abbandonato la chiamata",
    "_{user0}, {user1} and %n more participant left the call_::_{user0}, {user1} and %n more participants left the call_" : ["{user0}, {user1} e %n altro partecipante hanno abbandonato la chiamata ","{user0}, {user1} e %n altri partecipanti hanno abbandonato la chiamata ","{user0}, {user1} e %n altri partecipanti hanno abbandonato la chiamata "],
    "You promoted {user0} and {user1} to moderators" : "Hai promosso {user0} e {user1} a moderatori",
    "_You promoted {user0}, {user1} and %n more participant to moderators_::_You promoted {user0}, {user1} and %n more participants to moderators_" : ["Hai promosso {user0}, {user1} e %n altro partecipante a moderatori","Hai promosso {user0}, {user1} e %n altri partecipanti a moderatori","Hai promosso {user0}, {user1} e %n altri partecipanti a moderatori"],
    "An administrator promoted you and {user0} to moderators" : "Un amministratore ha promosso te e {user0} a moderatori",
    "{actor} promoted you and {user0} to moderators" : "{actor} ha promosso te e {user0} a moderatori",
    "_An administrator promoted you, {user0} and %n more participant to moderators_::_An administrator promoted you, {user0} and %n more participants to moderators_" : ["Un amministratore ha promosso te, {user0} e %n altro partecipante a moderatori","Un amministratore ha promosso te, {user0} e %n altri partecipanti a moderatori","Un amministratore ha promosso te, {user0} e %n altri partecipanti a moderatori"],
    "_{actor} promoted you, {user0} and %n more participant to moderators_::_{actor} promoted you, {user0} and %n more participants to moderators_" : ["{actor} ha promosso te, {user0} e %n altro partecipante a moderatori","{actor} ha promosso te, {user0} e altri %n partecipanti a moderatori","{actor} ha promosso te, {user0} e altri %n partecipanti a moderatori"],
    "An administrator promoted {user0} and {user1} to moderators" : "Un amministratore ha promosso {user0} e {user1} a moderatori",
    "{actor} promoted {user0} and {user1} to moderators" : "{actor} ha promosso {user0} e {user1} a moderatori",
    "_An administrator promoted {user0}, {user1} and %n more participant to moderators_::_An administrator promoted {user0}, {user1} and %n more participants to moderators_" : ["Un amministratore ha promosso {user0}, {user1} e %n altro partecipante a moderatori","Un amministratore ha promosso {user0}, {user1} e %n altri partecipanti a moderatori","Un amministratore ha promosso {user0}, {user1} e %n altri partecipanti a moderatori"],
    "_{actor} promoted {user0}, {user1} and %n more participant to moderators_::_{actor} promoted {user0}, {user1} and %n more participants to moderators_" : ["{actor} ha promosso {user0}, {user1} e %n altro partecipante a moderatori ","{actor} ha promosso {user0}, {user1} e %n altri partecipanti a moderatori ","{actor} ha promosso {user0}, {user1} e %n altri partecipanti a moderatori "],
    "You demoted {user0} and {user1} from moderators" : "Hai rimosso {user0} e {user1} dai moderatori",
    "_You demoted {user0}, {user1} and %n more participant from moderators_::_You demoted {user0}, {user1} and %n more participants from moderators_" : ["Hai rimosso {user0}, {user1} e %n altro partecipante dai moderatori","Hai rimosso {user0}, {user1} e %n altri partecipanti dai moderatori","Hai rimosso {user0}, {user1} e %n altri partecipanti dai moderatori"],
    "An administrator demoted you and {user0} from moderators" : "Un amministratore ha rimosso te e {user0} dai moderatori",
    "{actor} demoted you and {user0} from moderators" : "{actor} ha rimosso te e {user0} dai moderatori",
    "_An administrator demoted you, {user0} and %n more participant from moderators_::_An administrator demoted you, {user0} and %n more participants from moderators_" : ["Un amministratore ha rimosso te, {user0} e %n altro partecipante dai moderatori","Un amministratore ha rimosso te, {user0} e %n altri partecipanti dai moderatori","Un amministratore ha rimosso te, {user0} e %n altri partecipanti dai moderatori"],
    "_{actor} demoted you, {user0} and %n more participant from moderators_::_{actor} demoted you, {user0} and %n more participants from moderators_" : ["{actor} ha rimosso te, {user0} e %n altro partecipante dai moderatori","{actor} ha rimosso te, {user0} e %n altri partecipanti dai moderatori","{actor} ha rimosso te, {user0} e %n altri partecipanti dai moderatori"],
    "An administrator demoted {user0} and {user1} from moderators" : "Un amministratore ha rimosso {user0} e {user1} dai moderatori",
    "{actor} demoted {user0} and {user1} from moderators" : "{actor} ha rimosso {user0} e {user1} dai moderatori",
    "_An administrator demoted {user0}, {user1} and %n more participant from moderators_::_An administrator demoted {user0}, {user1} and %n more participants from moderators_" : ["Un amministratore ha rimosso {user0}, {user1} e %n altro partecipante dai moderatori","Un amministratore ha rimosso {user0}, {user1} e %n altri partecipanti dai moderatori","Un amministratore ha rimosso {user0}, {user1} e %n altri partecipanti dai moderatori"],
    "_{actor} demoted {user0}, {user1} and %n more participant from moderators_::_{actor} demoted {user0}, {user1} and %n more participants from moderators_" : ["{actor} ha rimosso {user0}, {user1} e %n altro partecipante dai moderatori","{actor} ha rimosso {user0}, {user1} e %n altri partecipanti dai moderatori","{actor} ha rimosso {user0}, {user1} e %n altri partecipanti dai moderatori"],
    "You:" : "Tu:",
    "You: {lastMessage}" : "Tu: {lastMessage}",
    "{actor}:" : "{actor}:",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "(edited by you)" : "(modificato da te)",
    "(edited by a deleted user)" : "(modificato da un utente eliminato)",
    "(edited by {moderator})" : "(modificato da {moderator})",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Stai tentando di partecipare a una conversazione mentre hai una sessione attiva in un'altra finestra o dispositivo. Questo non è attualmente supportato da Nextcloud Talk. Che cosa vuoi fare?",
    "Leave this page" : "Abbandona questa pagina",
    "Join here" : "Unisciti qui",
    "Deck card has been posted to {conversation}" : "La scheda di Deck è stata pubblicata su {conversation}",
    "An error occurred while posting deck card to conversation" : "Si è verificato un errore durante la pubblicazione della scheda di Deck nella conversazione",
    "Post to a conversation" : "Pubblica in una conversazione",
    "Post to conversation" : "Pubblica in conversazione",
    "The recording failed. Please contact your administrator." : "La registrazione è fallita. Per favore, contatta un amministratore.",
    "Location has been posted to {conversation}" : "La posizione è stata pubblicata su {conversation}",
    "An error occurred while posting location to conversation" : "Si è verificato un errore durante la pubblicazione della posizione nella conversazione",
    "Share to a conversation" : "Condividi in una conversazione",
    "Share to conversation" : "Condividi su conversazione",
    "In conversation" : "In conversazione",
    "Search in conversation: {conversation}" : "Cerca nella conversazione: {conversation}",
    "Your requests are throttled at the moment due to brute force protection" : "Le tue richieste sono attualmente limitate a causa della protezione contro gli attacchi brute force.",
    "Error while clearing conversation history" : "Errore durante la cancellazione della cronologia della conversazione",
    "Error occurred while allowing guests" : "Si è verificato un errore durante l'autorizzazione degli ospiti",
    "Error occurred while disallowing guests" : "Si è verificato un errore durante la disabilitazione degli ospiti",
    "Error occurred when restricting the conversation to moderator" : "Si è verificato un errore durante la limitazione della conversazione al moderatore",
    "Error occurred when opening the conversation to everyone" : "Si è verificato un errore durante l'apertura della conversazione a tutti",
    "Conversation password has been saved" : "La password della conversazione è stata salvata",
    "Conversation password has been removed" : "La password della conversazione è stata rimossa",
    "Error occurred while saving conversation password" : "Si è verificato un errore durante il salvataggio della password della conversazione",
    "Call recording is starting." : "La registrazione della chiamata sta iniziando",
    "Call recording stopped while starting." : "La registrazione della chiamata è stata interrotta prima dell'inizio.",
    "Call recording stopped. You will be notified once the recording is available." : "La registrazione della chiamata è stata interrotta. Riceverai una notifica non appena la registrazione sarà disponibile.",
    "Conversation picture set" : "Icona della conversazione impostata",
    "Conversation picture deleted" : "Icona della conversazione eliminata",
    "Could not delete the conversation picture" : "Impossibile eliminare l'icona della conversazione",
    "Could not remove the automatic expiration" : "Impossibile rimuovere la scadenza automatica",
    "Could not post message: {errorMessage}" : "Impossibile pubblicare il messaggio: {errorMessage}",
    "Participant is banned successfully" : "Il partecipante è stato bandito con successo",
    "Error while banning the participant" : "Errore durante il bando del partecipante",
    "An error occurred while fetching the participants" : "Si è verificato un errore durante il recupero dei partecipanti",
    "Could not send invitation to {actorId}" : "Impossibile inviare l'invito a {actorId}",
    "Invitations sent" : "Inviti inviati",
    "Error occurred when sending invitations" : "Si è verificato un errore durante l'invio degli inviti",
    "Failed to join the conversation." : "Impossibile entrare nelal conversazione.",
    "An error occurred while creating breakout rooms" : "Un errore è avvenuto durante la creazione di sessioni secondarie",
    "An error occurred while re-ordering the attendees" : "Un errore è avvenuto durante il riordino dei partecipanti",
    "An error occurred while deleting breakout rooms" : "Un errore è avvenuto durante l'eliminazione di sessioni secondarie",
    "An error occurred while starting breakout rooms" : "Un errore è avvenuto durante l'avvio delle sessioni secondarie",
    "An error occurred while stopping breakout rooms" : "Un errore è avvenuto durante l'interruzione delle sessioni secondarie",
    "An error occurred while sending a message to the breakout rooms" : "Un errore è avvenuto durante l'invio di un messaggio alle sessioni secondarie",
    "An error occurred while requesting assistance" : "Un errore è avvenuto durante la richiesta di assistenza",
    "An error occurred while resetting the request for assistance" : "Un errore è avvenuto durante il reset della richiesta di assistenza",
    "An error occurred while joining breakout room" : "Un errore è avvenuto durante l'ingresso nella sessione secondaria",
    "Failed to rename the thread" : "Impossibile rinominare l'argomento",
    "Error fetching upcoming events" : "Errore durante il recupero degli eventi imminenti",
    "Error fetching upcoming reminders" : "Errore durante il recupero dei promemoria imminenti",
    "An error occurred while accepting an invitation" : "Si è verificato un errore durante l'accettazione di un invito",
    "An error occurred while rejecting an invitation" : "Si è verificato un errore durante il rifiuto di un invito",
    "{guest} (guest)" : "{guest} (ospite)",
    "Poll draft has been saved" : "Bozza del sondaggio salvata",
    "An error occurred while saving the draft" : "Si è verificato un errore durante il salvataggio della bozza",
    "An error occurred while submitting your vote" : "Si è verificato un errore durante l'invio del voto",
    "An error occurred while ending the poll" : "Si è verificato un errore durante la chiusura del sondaggio",
    "An error occurred while deleting the poll draft" : "Si è verificato un errore durante l'eliminazione della bozza di sondaggio",
    "Poll \"{name}\" was created by {user}. Click to vote" : "Il sondaggio \"{name}\" è stato creato da {user}. Fai clic per votare",
    "Failed to add reaction" : "Impossibile aggiungere la reazione",
    "Failed to remove reaction" : "Impossibile rimuovere la reazione",
    "Error while uploading file \"{fileName}\"" : "Errore durante il caricamento del file \"{fileName}\"",
    "Not enough free space to upload file \"{fileName}\"" : "Spazio libero insufficiente per caricare il file \"{fileName}\"",
    "You are not allowed to share files" : "Non ti è consentito condividere file",
    "Error while sharing file" : "Errore durante la condivisione del file",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Il browser che stai utilizzando non è completamente supportato da Nextcloud Talk. Usa l'ultima versione di Mozilla Firefox, Microsoft Edge, Google Chrome, Opera o Apple Safari.",
    "_In %n hour_::_In %n hours_" : ["Tra %n ora","Tra %n ore","Tra %n ore"],
    "_%n minute _::_%n minutes_" : ["%n minuto","%n minuti","%n minuti"],
    "In {hours} and {minutes}" : "Tra {hours} e {minutes}",
    "_In %n minute_::_In %n minutes_" : ["Tra %n minuto","Tra %n minuti","Tra %n minuti"],
    "Later today – {timeLocale}" : "Oggi – {timeLocale}",
    "Tomorrow – {timeLocale}" : "Domani – {timeLocale}",
    "This weekend – {timeLocale}" : "Questo fine settimana – {timeLocale}",
    "Next week – {timeLocale}" : "Prossima settimana – {timeLocale}",
    "Conversation link copied to clipboard" : "Collegamento alla conversazione copiato negli appunti",
    "The link could not be copied" : "Impossibile copiare il collegamento",
    "Error while parsing a PROPFIND error" : "Errore durante l'elaborazione di un errore PROPFIND",
    "Sending signaling message has failed" : "Invio del messaggio di segnalazione non riuscito",
    "Lost connection to signaling server. Trying to reconnect." : "Connessione al server di segnalazione interrotta. Riprova a connetterti.",
    "Lost connection to signaling server." : "Connessione persa con il server di segnalazione.",
    "The configured signaling server needs to be updated to be compatible with this version of Talk. Please contact your administration." : "Il server di segnalazione configurato deve essere aggiornato per essere compatibile con questa versione di Talk. Contatta l'amministratore.",
    "Please restart the app." : "Riavvia l'applicazione.",
    "Please reload the page." : "Ricarica la pagina.",
    "Please try to restart the app." : "Prova a riavviare l'applicazione.",
    "Please try to reload the page." : "Per favore prova a ricaricare la pagina.",
    "Do not disturb" : "Non disturbare",
    "Away" : "Assente",
    "Microphone {number}" : "Microfono {number}",
    "Camera {number}" : "Fotocamera {number}",
    "Speaker {number}" : "Altoparlante {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Sembra che tu abbia parlato mentre eri silenziato, rimuovi il silenzio perché gli altri possano sentirti",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "Impossibile stabilire una connessione con almeno un partecipante. Un server TURN potrebbe essere necessario in questo scenario. Chiedi al tuo amministratore di configurarne uno seguendo {linkstart}questa documentazione{linkend}.",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "L'operazione sta richiedendo più tempo del previsto. I permessi multimediali sono già stati accordati (o rifiutati)? Se sì, riavvia il browser, poiché audio e video non funzionano",
    "Access to microphone & camera is only possible with HTTPS" : "L'accesso a microfono e fotocamera è possibile solo con HTTPS",
    "Please move your setup to HTTPS" : "Sposta la tua configurazione su HTTPS",
    "Access to microphone & camera was denied" : "L'accesso a microfono e fotocamera è stato negato",
    "WebRTC is not supported in your browser" : "WebRTC non è supportato dal tuo browser",
    "Please use a different browser like Firefox or Chrome" : "Utilizza un browser diverso come Firefox o Chrome",
    "Error while accessing microphone & camera" : "Errore durante l'accesso a microfono e fotocamera",
    "%s Talk on your mobile devices" : "%s Talk sui tuoi dispositivi mobili ",
    "Join conversations at any time, anywhere, on any device." : "Unisciti alle conversazioni in qualsiasi momento, ovunque, su qualsiasi dispositivo.",
    "Android app" : "Applicazione Android",
    "iOS app" : "Applicazione iOS",
    "__language_name__" : "Italiano",
    "Webhook Demo" : "Demo Webhook",
    "Call summary (%s)" : "Riassunto della chiamata (%s)",
    "The call summary bot posts an overview message after the call listing all participants and outlining tasks" : "Il bot di riassunto delle chiamate pubblica un messaggio di sintesi dopo la chiamata, elencando tutti i partecipanti e descrivendo le attività.",
    "Tasks" : "Attività",
    "Notes" : "Note",
    "Reports" : "Reports",
    "Decisions" : "Decisioni",
    "Agenda" : "Agenda",
    "Call summary" : "Riassunto della chiamata",
    "Call summary - {title}" : "Riassunto della chiamata - {title}",
    "Talk conversation for event" : "Conversazione di Talk per un evento",
    "Client Push is installed, this improves the performance of desktop clients." : "Client Push è installato, questo migliora le prestazioni dei client desktop.",
    "{notify_push} is not installed, this might lead to performance issues when using desktop clients." : "{notify_push} non è installato, ciò potrebbe causare problemi di prestazioni durante l'utilizzo dei client desktop.",
    "Next meeting" : "Prossimo meeting",
    "Schedule a meeting from your calendar. A Talk conversation needs to be set as location to show up here" : "Pianifica un meeting dal tuo calendario. Una conversazione Talk deve essere impostata come posizione per essere visualizzata qui.",
    "Join conversations from remote Nextcloud servers" : "Partecipa alle conversazioni dai server Nextcloud remoti",
    "Your default media state has been saved" : "Il tuo stato predefinito dei media è stato salvato",
    "Set reminder for later today" : "Imposta promemoria per più tardi oggi",
    "Set reminder for tomorrow" : "Imposta promemoria per domani",
    "Set reminder for this weekend" : "Imposta promemoria per questo fine settimana",
    "Set reminder for next week" : "Imposta promemoria per la prossima settimana",
    "Generate summary" : "Genera riassunto",
    "Open poll • You voted already" : "Sondaggio aperto • Hai già votato",
    "Open poll • Click to vote" : "Sondaggio aperto • Fai clic per votare",
    "Poll • Ended" : "Sondaggio • Terminato",
    "Talk recording from {time} ({conversation})" : "Registrazione della conversazione da {time} ({conversation})",
    "_Poll results • %n vote_::_Poll results • %n votes_" : ["Risultati del sondaggio • %n voto","Risultati del sondaggio • %n voti","Risultati del sondaggio • %n voti"],
    "_Open poll • %n vote_::_Open poll • %n votes_" : ["Sondaggio aperto • %n voto","Sondaggio aperto • %n voti","Sondaggio aperto • %n voti"],
    "Submit vote" : "Invia voto",
    "Your privacy setting has been saved" : "Le tue impostazioni di riservatezza sono state salvate",
    "Your personal setting has been saved" : "Le tue impostazioni personali sono state salvate",
    "Failed to save sounds setting" : "Errore nel salvare le impostazioni dei suoni ",
    "Sounds setting saved" : "Impostazione dei suoni salvata",
    "Nextcloud Talk was updated, you cannot start or join a call." : "Nextcloud Talk è stato aggiornato, non è possibile avviare o partecipare a una chiamata.",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Ti sei unito alla conversazione in un'altra finestra o dispositivo. Questo non è attualmente supportato da Nextcloud Talk, quindi questa sessione è stata chiusa.",
    "Nextcloud Talk was updated." : "Nextcloud Talk è stato aggiornato.",
    "Nextcloud is in maintenance mode." : "Nextcloud è in modalità manutenzione.",
    "Nextcloud Talk Federation was updated." : "Nextcloud Talk Federation è stato aggiornato."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
